@@ -15,28 +15,21 @@
 #
 # You should have received a copy of the GNU General Public License
 # along with this program; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #
 
-# $Id$
-
 """
-Package providing filtering framework for GRAMPS.
+Package providing filtering framework for Gramps.
 """
 
-from gramps.gen.constfunc import win
-
-class SearchFilter(object):
+class SearchFilter:
     def __init__(self, func, text, invert):
         self.func = func
         self.text = text.upper()
         self.invert = invert
 
     def match(self, handle, db):
-        if win():
-            return self.invert ^ (self.func(handle).upper().find(str(self.text)) != -1)
-        else:
-            return self.invert ^ (self.func(handle).upper().find(self.text) != -1)
+        return self.invert ^ (self.func(handle).upper().find(self.text) != -1)
 
 class ExactSearchFilter(SearchFilter):
     def __init__(self, func, text, invert):
@@ -44,4 +37,4 @@ class ExactSearchFilter(SearchFilter):
 
     def match(self, handle, db):
         return self.invert ^ (self.func(handle).upper() == self.text.strip())
-    
+
