@@ -29,7 +29,7 @@ _ = glocale.translation.gettext
 
 #-------------------------------------------------------------------------
 #
-# GRAMPS modules
+# Gramps modules
 #
 #-------------------------------------------------------------------------
 from . import Rule
@@ -40,12 +40,12 @@ from . import Rule
 #
 #-------------------------------------------------------------------------
 class HasGrampsId(Rule):
-    """Rule that checks for an object with a specific GRAMPS ID."""
+    """Rule that checks for an object with a specific Gramps ID."""
 
-    labels      = [ _('ID:') ]
-    name        = 'Object with <Id>'
+    labels = [ _('ID:') ]
+    name = 'Object with <Id>'
     description = "Matches objects with a specified Gramps ID"
-    category    = _('General filters')
+    category = _('General filters')
 
     def apply(self, db, obj):
         """
