@@ -29,7 +29,7 @@ _ = glocale.translation.gettext
 
 #-------------------------------------------------------------------------
 #
-# GRAMPS modules
+# Gramps modules
 #
 #-------------------------------------------------------------------------
 from . import Rule
@@ -42,12 +42,12 @@ from . import Rule
 class HasSourceOfBase(Rule):
     """Rule that checks for objects that have a particular source."""
 
-    labels      = [ _('Source ID:') ]
-    name        = 'Object with the <source>'
-    category    = _('Citation/source filters')
+    labels = [ _('Source ID:') ]
+    name = 'Object with the <source>'
+    category = _('Citation/source filters')
     description = 'Matches objects who have a particular source'
-    
-    def prepare(self,db):
+
+    def prepare(self, db, user):
         if self.list[0] == '':
             self.source_handle = None
             self.nosource = True
