@@ -16,7 +16,7 @@
 #
 # You should have received a copy of the GNU General Public License
 # along with this program; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #
 
 """
@@ -25,7 +25,7 @@ LdsOrdBase class for Gramps.
 
 #-------------------------------------------------------------------------
 #
-# GRAMPS modules
+# Gramps modules
 #
 #-------------------------------------------------------------------------
 from .ldsord import LdsOrd
@@ -36,25 +36,25 @@ from .const import IDENTICAL, EQUAL
 # LdsOrdBase classes
 #
 #-------------------------------------------------------------------------
-class LdsOrdBase(object):
+class LdsOrdBase:
     """
     Base class for lds_ord-aware objects.
     """
 
     def __init__(self, source=None):
         """
-        Initialize a LdsOrdBase. 
-        
-        If the source is not None, then object is initialized from values of 
+        Initialize a LdsOrdBase.
+
+        If the source is not None, then object is initialized from values of
         the source object.
 
         :param source: Object used to initialize the new object
         :type source: LdsOrdBase
         """
-        
+
         if source:
             self.lds_ord_list = [LdsOrd(lds_ord)
-                                    for lds_ord in source.lds_ord_list]
+                                 for lds_ord in source.lds_ord_list]
         else:
             self.lds_ord_list = []
 
@@ -64,37 +64,6 @@ class LdsOrdBase(object):
         """
         return [lds_ord.serialize() for lds_ord in self.lds_ord_list]
 
-    def to_struct(self):
-        """
-        Convert the data held in this object to a structure (eg,
-        struct) that represents all the data elements.
-        
-        This method is used to recursively convert the object into a
-        self-documenting form that can easily be used for various
-        purposes, including diffs and queries.
-
-        These structures may be primitive Python types (string,
-        integer, boolean, etc.) or complex Python types (lists,
-        tuples, or dicts). If the return type is a dict, then the keys
-        of the dict match the fieldname of the object. If the return
-        struct (or value of a dict key) is a list, then it is a list
-        of structs. Otherwise, the struct is just the value of the
-        attribute.
-
-        :returns: Returns a struct containing the data of the object.
-        :rtype: list
-        """
-        return [lds_ord.to_struct() for lds_ord in self.lds_ord_list]
-
-    @classmethod
-    def from_struct(cls, struct):
-        """
-        Given a struct data representation, return a serialized object.
-
-        :returns: Returns a serialized object
-        """
-        return [LdsOrd.from_struct(lds_ord) for lds_ord in struct]
-
     def unserialize(self, data):
         """
         Convert a serialized tuple of data to an object
@@ -116,7 +85,7 @@ class LdsOrdBase(object):
         """
         Remove the specified :class:`~.ldsord.LdsOrd` instance from the lds_ord
         list.
-        
+
         If the instance does not exist in the list, the operation has no effect.
 
         :param lds_ord: :class:`~.ldsord.LdsOrd` instance to remove from the
@@ -147,7 +116,7 @@ class LdsOrdBase(object):
         """
         Assign the passed list to the object's list of :class:`~.ldsord.LdsOrd`
         instances.
-        
+
         :param lds_ord_list: List of :class:`~.ldsord.LdsOrd` instances to be
                              associated with the object
         :type lds_ord_list: list
