@@ -1,7 +1,7 @@
 #
 # Gramps - a GTK+/GNOME based genealogy program
 #
-# Copyright (C) 2010      Nick Hall
+# Copyright (C) 2010,2017 Nick Hall
 # Copyright (C) 2013      Doug Blank <doug.blank@gmail.com>
 #
 # This program is free software; you can redistribute it and/or modify
@@ -25,17 +25,19 @@ Table Object class for Gramps.
 
 #-------------------------------------------------------------------------
 #
-# standard python modules
+# Standard Python modules
 #
 #-------------------------------------------------------------------------
+from abc import abstractmethod
 import time
 
 #-------------------------------------------------------------------------
 #
-# GRAMPS modules
+# Gramps modules
 #
 #-------------------------------------------------------------------------
 from .baseobj import BaseObject
+from ..errors import HandleError
 
 #-------------------------------------------------------------------------
 #
@@ -56,14 +58,14 @@ class TableObject(BaseObject):
     changed time.  The database handle is used as the unique key for a record
     in the database.  This is not the same as the Gramps ID, which is a user
     visible identifier for a record.
-    
-    It is the base class for the BasicPrimaryObject class and Tag class.    
+
+    It is the base class for the BasicPrimaryObject class and Tag class.
     """
-    
+
     def __init__(self, source=None):
         """
-        Initialize a TableObject. 
-        
+        Initialize a TableObject.
+
         If source is None, the handle is assigned as an empty string.
         If source is not None, then the handle is initialized from the value in
         the source object.
@@ -78,13 +80,25 @@ class TableObject(BaseObject):
             self.handle = None
             self.change = 0
 
+    @abstractmethod
+    def serialize(self):
+        """
+        Convert the object to a serialized tuple of data.
+        """
+
+    @abstractmethod
+    def unserialize(self, data):
+        """
+        Convert a serialized tuple of data to an object.
+        """
+
     def get_change_time(self):
         """
-        Return the time that the data was last changed. 
-        
+        Return the time that the data was last changed.
+
         The value in the format returned by the :meth:`time.time()` command.
-           
-        :returns: Time that the data was last changed. The value in the format 
+
+        :returns: Time that the data was last changed. The value in the format
                   returned by the :meth:`time.time()` command.
         :rtype: int
         """
@@ -92,8 +106,8 @@ class TableObject(BaseObject):
 
     def set_change_time(self, change):
         """
-        Modify the time that the data was last changed. 
-        
+        Modify the time that the data was last changed.
+
         The value must be in the format returned by the :meth:`time.time()`
         command.
 
@@ -108,11 +122,11 @@ class TableObject(BaseObject):
 
         :returns: string representation of the last change time.
         :rtype: str
-        
+
         """
         if self.change:
             return str(time.strftime('%x %X', time.localtime(self.change)),
-                           CODESET)
+                       CODESET)
         else:
             return ''
 
@@ -133,3 +147,29 @@ class TableObject(BaseObject):
         :rtype: str
         """
         return self.handle
+
+    @classmethod
+    def get_schema(cls):
+        """
+        Return schema.
+        """
+        return {}
+
+    @classmethod
+    def get_secondary_fields(cls):
+        """
+        Return all secondary fields and their types
+        """
+        result = []
+        for (key, value) in cls.get_schema()["properties"].items():
+            schema_type = value.get("type")
+            if isinstance(schema_type, list):
+                schema_type.remove("null")
+                schema_type = schema_type[0]
+            elif isinstance(schema_type, dict):
+                schema_type = None
+            if schema_type in ("string", "integer", "number", "boolean"):
+                result.append((key.lower(),
+                               schema_type,
+                               value.get("maxLength")))
+        return result
