@@ -31,7 +31,7 @@
 
 #-------------------------------------------------------------------------
 #
-# GRAMPS modules
+# Gramps modules
 #
 #-------------------------------------------------------------------------
 
@@ -50,15 +50,15 @@ log = logging.getLogger(".fontstyle")
 #
 #-------------------------------------------------------------------------
 FONT_SANS_SERIF = 0
-FONT_SERIF      = 1
-FONT_MONOSPACE  = 2
+FONT_SERIF = 1
+FONT_MONOSPACE = 2
 
 #------------------------------------------------------------------------
 #
 # FontStyle
 #
 #------------------------------------------------------------------------
-class FontStyle(object):
+class FontStyle:
     """
     Defines a font style. Controls the font face, size, color, and
     attributes. In order to remain generic, the only font faces available
@@ -69,7 +69,7 @@ class FontStyle(object):
     guarentees that the document format generator will be able implement
     all or any of the characteristics.
     """
-    
+
     def __init__(self, style=None):
         """
         Create a new FontStyle object, accepting the default values.
@@ -78,20 +78,20 @@ class FontStyle(object):
                       FontStyle instead of using the defaults.
         """
         if style:
-            self.face   = style.face
-            self.size   = style.size
+            self.face = style.face
+            self.size = style.size
             self.italic = style.italic
-            self.bold   = style.bold
-            self.color  = style.color
-            self.under  = style.under
+            self.bold = style.bold
+            self.color = style.color
+            self.under = style.under
         else:
-            self.face   = FONT_SERIF
-            self.size   = 12
+            self.face = FONT_SERIF
+            self.size = 12
             self.italic = 0
-            self.bold   = 0
-            self.color  = (0, 0, 0)
-            self.under  = 0
-            
+            self.bold = 0
+            self.color = (0, 0, 0)
+            self.under = 0
+
     def set(self, face=None, size=None, italic=None, bold=None,
             underline=None, color=None):
         """
