@@ -24,8 +24,6 @@
 # Python classes
 #
 #-------------------------------------------------------------------------
-from gramps.gen.const import GRAMPS_LOCALE as glocale
-_ = glocale.translation.gettext
 
 #-------------------------------------------------------------------------
 #
@@ -37,12 +35,15 @@ from gi.repository import Gdk
 
 #-------------------------------------------------------------------------
 #
-# GRAMPS classes
+# Gramps classes
 #
 #-------------------------------------------------------------------------
+from gramps.gen.const import GRAMPS_LOCALE as glocale
+_ = glocale.translation.gettext
 from ...widgets import SimpleButton
 from .grampstab import GrampsTab
 from gramps.gen.errors import WindowActiveError
+from ...utils import match_primary_mask
 
 _KP_ENTER = Gdk.keyval_from_name("KP_Enter")
 _RETURN = Gdk.keyval_from_name("Return")
@@ -72,13 +73,16 @@ class ButtonTab(GrampsTab):
         'jump'  : _('Jump To'),
         'up'    : _('Move Up'),
         'down'  : _('Move Down'),
+        'left'  : _('Move Left'),
+        'right' : _('Move right')
     }
-    
+    L_R = 2  # indicator for left/right move buttons
+
     def __init__(self, dbstate, uistate, track, name, share_button=False,
                     move_buttons=False, jump_button=False, top_label=None):
         """
         Similar to the base class, except after Build.
-        
+
         @param dbstate: The database state. Contains a reference to
         the database, along with other state information. The GrampsTab
         uses this to access the database and to pass to and created
@@ -105,13 +109,13 @@ class ButtonTab(GrampsTab):
         GrampsTab.__init__(self,dbstate, uistate, track, name)
         self._create_buttons(share_button, move_buttons, jump_button, top_label)
 
-    def _create_buttons(self, share_button, move_buttons, jump_button, 
+    def _create_buttons(self, share_button, move_buttons, jump_button,
                          top_label):
         """
         Create a button box consisting of three buttons, one for Add,
-        one for Edit, and one for Delete. 
-        
-        Add buttons for Share, Move and Jump depending on parameters. This 
+        one for Edit, and one for Delete.
+
+        Add buttons for Share, Move and Jump depending on parameters. This
         button box is then appended hbox (self).
         Prepend a label if top_label given
 
@@ -122,9 +126,9 @@ class ButtonTab(GrampsTab):
             self.top_label.set_use_markup(True)
             self.track_ref_for_deletion("top_label")
 
-        self.add_btn  = SimpleButton('list-add', self.add_button_clicked)
+        self.add_btn = SimpleButton('list-add', self.add_button_clicked)
         self.edit_btn = SimpleButton('gtk-edit', self.edit_button_clicked)
-        self.del_btn  = SimpleButton('list-remove', self.del_button_clicked)
+        self.del_btn = SimpleButton('list-remove', self.del_button_clicked)
         self.track_ref_for_deletion("add_btn")
         self.track_ref_for_deletion("edit_btn")
         self.track_ref_for_deletion("del_btn")
@@ -132,19 +136,23 @@ class ButtonTab(GrampsTab):
         self.add_btn.set_tooltip_text(self._MSG['add'])
         self.edit_btn.set_tooltip_text(self._MSG['edit'])
         self.del_btn.set_tooltip_text(self._MSG['del'])
-        
+
         if share_button:
             self.share_btn = SimpleButton('gtk-index', self.share_button_clicked)
             self.share_btn.set_tooltip_text(self._MSG['share'])
             self.track_ref_for_deletion("share_btn")
         else:
             self.share_btn = None
-            
+
         if move_buttons:
-            self.up_btn = SimpleButton('go-up', self.up_button_clicked)
-            self.up_btn.set_tooltip_text(self._MSG['up'])
-            self.down_btn = SimpleButton('go-down', self.down_button_clicked)
-            self.down_btn.set_tooltip_text(self._MSG['down'])
+            l_r = move_buttons == self.L_R
+            self.up_btn = SimpleButton('go-previous' if l_r else 'go-up',
+                                       self.up_button_clicked)
+            self.up_btn.set_tooltip_text(self._MSG['left' if l_r else 'up'])
+            self.down_btn = SimpleButton('go-next' if l_r else 'go-down',
+                                         self.down_button_clicked)
+            self.down_btn.set_tooltip_text(
+                self._MSG['right' if l_r else 'down'])
             self.track_ref_for_deletion("up_btn")
             self.track_ref_for_deletion("down_btn")
         else:
@@ -192,7 +200,8 @@ class ButtonTab(GrampsTab):
         Handles the double click on list. If the double click occurs,
         the Edit button handler is called
         """
-        if event.type == Gdk.EventType._2BUTTON_PRESS and event.button == 1:
+        if (event.type == Gdk.EventType.DOUBLE_BUTTON_PRESS
+                and event.button == 1):
             try:
                 self.edit_button_clicked(obj)
             except WindowActiveError:
@@ -219,7 +228,7 @@ class ButtonTab(GrampsTab):
                     return
                 self.add_button_clicked(obj)
             elif event.keyval in (_OPEN,) and self.share_btn and \
-                    (event.get_state() & Gdk.ModifierType.CONTROL_MASK):
+                    match_primary_mask(event.get_state()):
                 self.share_button_clicked(obj)
             elif event.keyval in (_LEFT,) and \
                     (event.get_state() & Gdk.ModifierType.MOD1_MASK):
@@ -266,17 +275,17 @@ class ButtonTab(GrampsTab):
         class.
         """
         print("Uncaught Edit clicked")
-        
+
     def up_button_clicked(self, obj):
         """
-        Function called with the Up button is clicked. 
+        Function called with the Up button is clicked.
         This function should be overridden by the derived class.
         """
         print("Uncaught Up clicked")
-        
+
     def down_button_clicked(self, obj):
         """
-        Function called with the Down button is clicked. 
+        Function called with the Down button is clicked.
         This function should be overridden by the derived class.
         """
         print("Uncaught Down clicked")
@@ -289,7 +298,7 @@ class ButtonTab(GrampsTab):
         """
         # Comparing to None is important, as empty strings
         # and 0 can be returned
-        # This method is called as callback on change, and can be called 
+        # This method is called as callback on change, and can be called
         # explicitly, dirty_selection must make sure they do not interact
         if self.dirty_selection:
             return
