@@ -38,11 +38,11 @@ from gi.repository import Pango
 WEIGHT_NORMAL = Pango.Weight.NORMAL
 WEIGHT_BOLD = Pango.Weight.BOLD
 
-import cgi
+from html import escape
 
 #-------------------------------------------------------------------------
 #
-# GRAMPS classes
+# Gramps classes
 #
 #-------------------------------------------------------------------------
 from ...widgets.undoablebuffer import UndoableBuffer
@@ -50,6 +50,7 @@ from gramps.gen.lib import EventRoleType
 from gramps.gen.datehandler import get_date, get_date_valid
 from gramps.gen.config import config
 from gramps.gen.utils.db import get_participant_from_event
+from gramps.gen.display.place import displayer as place_displayer
 
 #-------------------------------------------------------------------------
 #
@@ -57,7 +58,7 @@ from gramps.gen.utils.db import get_participant_from_event
 #
 #-------------------------------------------------------------------------
 invalid_date_format = config.get('preferences.invalid-date-format')
-age_precision       = config.get('preferences.age-display-precision')
+age_precision = config.get('preferences.age-display-precision')
 
 #-------------------------------------------------------------------------
 #
@@ -66,9 +67,9 @@ age_precision       = config.get('preferences.age-display-precision')
 #-------------------------------------------------------------------------
 class EventRefModel(Gtk.TreeStore):
     #index of the working group
-    _ROOTINDEX = 0 
+    _ROOTINDEX = 0
     _GROUPSTRING = _('%(groupname)s - %(groupnumber)d')
-    
+
     COL_DESCR = (0, str)
     COL_TYPE = (1, str)
     COL_GID = (2, str)
@@ -82,15 +83,15 @@ class EventRefModel(Gtk.TreeStore):
     COL_AGE = (10, str)
     COL_SORTAGE = (11, str)
     COL_PRIVATE = (12, bool)
-    
-    COLS = (COL_DESCR, COL_TYPE, COL_GID, COL_DATE, COL_PLACE, COL_ROLE, 
+
+    COLS = (COL_DESCR, COL_TYPE, COL_GID, COL_DATE, COL_PLACE, COL_ROLE,
             COL_PARTIC, COL_SORTDATE, COL_EVENTREF, COL_FONTWEIGHT, COL_AGE,
             COL_SORTAGE, COL_PRIVATE)
 
     def __init__(self, event_list, db, groups, **kwargs):
         """
         @param event_list: A list of lists, every entry is a group, the entries
-            in a group are the data that needs to be shown subordinate to the 
+            in a group are the data that needs to be shown subordinate to the
             group
         @param db: a database objects that can be used to obtain info
         @param groups: a list of (key, name) tuples. key is a key for the group
@@ -111,7 +112,7 @@ class EventRefModel(Gtk.TreeStore):
     def row_group(self, index, group):
         name = self.namegroup(index, len(group))
         spouse = self.groups[index][2]
-        return ['', name, '', '', '', '', spouse, '', (index, None),
+        return [spouse, name, '', '', '', '', '', '', (index, None),
                 WEIGHT_BOLD, '', '', None]
 
     def namegroup(self, groupindex, length):
@@ -121,10 +122,10 @@ class EventRefModel(Gtk.TreeStore):
     def row(self, index, eventref, event):
         return [event.get_description(),
                 str(event.get_type()),
-                event.get_gramps_id(), 
-                self.column_date(eventref), 
-                self.column_place(eventref), 
-                self.column_role(eventref), 
+                event.get_gramps_id(),
+                self.column_date(eventref),
+                self.column_place(eventref),
+                self.column_role(eventref),
                 self.column_participant(eventref),
                 self.column_sort_date(eventref),
                 (index, eventref),
@@ -133,7 +134,7 @@ class EventRefModel(Gtk.TreeStore):
                 self.column_sort_age(event),
                 eventref.get_privacy(),
                ]
-    
+
     def colweight(self, index):
         return WEIGHT_NORMAL
 
@@ -144,7 +145,7 @@ class EventRefModel(Gtk.TreeStore):
         event = self.db.get_event_from_handle(event_ref.ref)
         retval = get_date(event)
         if not get_date_valid(event):
-            return invalid_date_format % cgi.escape(retval)
+            return invalid_date_format % escape(retval)
         else:
             return retval
 
@@ -160,17 +161,11 @@ class EventRefModel(Gtk.TreeStore):
         if event_ref and event_ref.ref:
             event = self.db.get_event_from_handle(event_ref.ref)
             if event:
-                place_handle = event.get_place_handle()
-                if place_handle:
-                    return self.db.get_place_from_handle(place_handle).get_title()
+                return place_displayer.display_event(self.db, event)
         return ""
 
     def column_participant(self, event_ref):
-        if int(event_ref.get_role()) not in (EventRoleType.PRIMARY,
-                                             EventRoleType.FAMILY):
-            return get_participant_from_event(self.db, event_ref.ref)
-        else:
-            return ""
+        return get_participant_from_event(self.db, event_ref.ref)
 
     def column_age(self, event):
         """
