@@ -48,9 +48,9 @@ from .editprimary import EditPrimary
 from .objectentries import PlaceEntry
 from ..glade import Glade
 from ..dialog import ErrorDialog
-from .displaytabs import (CitationEmbedList, NoteTab, GalleryTab, 
+from .displaytabs import (CitationEmbedList, NoteTab, GalleryTab,
                           EventBackRefList, EventAttrEmbedList)
-from ..widgets import (MonitoredEntry, PrivacyButton, MonitoredDataType, 
+from ..widgets import (MonitoredEntry, PrivacyButton, MonitoredDataType,
                        MonitoredDate, MonitoredTagList)
 from gramps.gen.utils.db import get_participant_from_event
 
@@ -73,7 +73,7 @@ class EditEvent(EditPrimary):
     def __init__(self, dbstate, uistate, track, event, callback=None):
 
         EditPrimary.__init__(self, dbstate, uistate, track,
-                             event, dbstate.db.get_event_from_handle, 
+                             event, dbstate.db.get_event_from_handle,
                              dbstate.db.get_event_from_gramps_id)
 
         self._init_event()
@@ -105,12 +105,10 @@ class EditEvent(EditPrimary):
                       key=lambda s: s.lower())
 
     def _local_init(self):
-        self.width_key = 'interface.event-width'
-        self.height_key = 'interface.event-height'
-
         self.top = Glade()
-        self.set_window(self.top.toplevel, None, 
+        self.set_window(self.top.toplevel, None,
                         self.get_menu_title())
+        self.setup_configs('interface.event', 600, 450)
 
         self.place = self.top.get_object('place')
         self.share_btn = self.top.get_object('select_place')
@@ -126,35 +124,37 @@ class EditEvent(EditPrimary):
 
     def _connect_db_signals(self):
         """
-        Connect any signals that need to be connected. 
+        Connect any signals that need to be connected.
         Called by the init routine of the base class (_EditPrimary).
         """
         self._add_db_signal('event-rebuild', self._do_close)
         self._add_db_signal('event-delete', self.check_for_close)
+        self._add_db_signal('place-delete', self.place_delete)
+        self._add_db_signal('place-update', self.place_update)
 
     def _setup_fields(self):
 
         # place, select_place, add_del_place
-        
+
         self.place_field = PlaceEntry(self.dbstate, self.uistate, self.track,
                                       self.top.get_object("place"),
                                       self.top.get_object("place_event_box"),
                                       self.obj.set_place_handle,
                                       self.obj.get_place_handle,
                                       self.add_del_btn, self.share_btn)
-        
+
         self.descr_field = MonitoredEntry(self.top.get_object("event_description"),
                                           self.obj.set_description,
-                                          self.obj.get_description, 
+                                          self.obj.get_description,
                                           self.db.readonly)
 
         self.gid = MonitoredEntry(self.top.get_object("gid"),
                                   self.obj.set_gramps_id,
                                   self.obj.get_gramps_id, self.db.readonly)
 
-        self.tags = MonitoredTagList(self.top.get_object("tag_label"), 
-                                     self.top.get_object("tag_button"), 
-                                     self.obj.set_tag_list, 
+        self.tags = MonitoredTagList(self.top.get_object("tag_label"),
+                                     self.top.get_object("tag_button"),
+                                     self.obj.set_tag_list,
                                      self.obj.get_tag_list,
                                      self.db,
                                      self.uistate, self.track,
@@ -171,7 +171,7 @@ class EditEvent(EditPrimary):
         self.date_field = MonitoredDate(self.top.get_object("date_entry"),
                                         self.top.get_object("date_stat"),
                                         self.obj.get_date_object(),
-                                        self.uistate, self.track, 
+                                        self.uistate, self.track,
                                         self.db.readonly)
 
     def _create_tabbed_pages(self):
@@ -184,17 +184,17 @@ class EditEvent(EditPrimary):
         self.citation_list = CitationEmbedList(self.dbstate,
                                                self.uistate,
                                                self.track,
-                                               self.obj.get_citation_list(), 
+                                               self.obj.get_citation_list(),
                                                self.get_menu_title())
         self._add_tab(notebook, self.citation_list)
-        
+
         self.note_list = NoteTab(self.dbstate,
                                  self.uistate,
                                  self.track,
                                  self.obj.get_note_list(),
                                  notetype=NoteType.EVENT)
         self._add_tab(notebook, self.note_list)
-        
+
 
         self.gallery_list = GalleryTab(self.dbstate,
                                        self.uistate,
@@ -216,7 +216,7 @@ class EditEvent(EditPrimary):
         self._add_tab(notebook, self.backref_list)
 
         self._setup_notebook_tabs(notebook)
-        
+
         notebook.show_all()
         self.top.get_object('vbox').pack_start(notebook, True, True, 0)
 
@@ -230,7 +230,7 @@ class EditEvent(EditPrimary):
         return (_('Edit Event'), self.get_menu_title())
 
     def help_clicked(self, obj):
-        """Display the relevant portion of GRAMPS manual"""
+        """Display the relevant portion of Gramps manual"""
         display_help(webpage=WIKI_HELP_PAGE, section=WIKI_HELP_SEC)
 
     def save(self, *obj):
@@ -242,14 +242,14 @@ class EditEvent(EditPrimary):
                         parent=self.window)
             self.ok_button.set_sensitive(True)
             return
-        
+
         (uses_dupe_id, id) = self._uses_duplicate_id()
         if uses_dupe_id:
             prim_object = self.get_from_gramps_id(id)
             name = prim_object.get_description()
             msg1 = _("Cannot save event. ID already exists.")
             msg2 = _("You have attempted to use the existing Gramps ID with "
-                         "value %(id)s. This value is already used by '" 
+                         "value %(id)s. This value is already used by '"
                          "%(prim_object)s'. Please enter a different ID or leave "
                          "blank to get the next available ID value.") % {
                          'id' : id, 'prim_object' : name }
@@ -261,7 +261,8 @@ class EditEvent(EditPrimary):
         if t.is_custom() and str(t) == '':
             ErrorDialog(
                 _("Cannot save event"),
-                _("The event type cannot be empty"), parent=self.window)
+                _("The event type cannot be empty"),
+                parent=self.window)
             self.ok_button.set_sensitive(True)
             return
 
@@ -270,17 +271,16 @@ class EditEvent(EditPrimary):
                        self.db) as trans:
                 self.db.add_event(self.obj, trans)
         else:
-            orig = self.get_from_handle(self.obj.handle)
-            if self.obj.serialize() != orig.serialize():
+            if self.data_has_changed():
                 with DbTxn(_("Edit Event (%s)") % self.obj.get_gramps_id(),
                            self.db) as trans:
                     if not self.obj.get_gramps_id():
                         self.obj.set_gramps_id(self.db.find_next_event_gramps_id())
-                    self.commit_event(self.obj, trans)
+                    self.db.commit_event(self.obj, trans)
 
         if self.callback:
             self.callback(self.obj)
-        self.close()
+        self._do_close()
 
     def data_has_changed(self):
         """
@@ -289,7 +289,7 @@ class EditEvent(EditPrimary):
         entered date when importing from a XML file, so we can get an
         incorrect fail.
         """
-        
+
         if self.db.readonly:
             return False
         elif self.obj.handle:
@@ -303,12 +303,30 @@ class EditEvent(EditPrimary):
             cmp_obj = self.empty_object()
             return cmp_obj.serialize(True)[1:] != self.obj.serialize()[1:]
 
+    def place_update(self, hndls):
+        ''' Place changed outside of dialog, update text if its ours '''
+        handle = self.obj.get_place_handle()
+        if handle and handle in hndls:
+            place = self.db.get_place_from_handle(handle)
+            p_lbl = "%s [%s]" % (place.get_title(), place.gramps_id)
+            self.top.get_object("place").set_text(p_lbl)
+
+    def place_delete(self, hndls):
+        ''' Place deleted outside of dialog, remove it if its ours'''
+        handle = self.obj.get_place_handle()
+        if handle and handle in hndls:
+            self.obj.set_place_handle(None)
+            self.top.get_object("place").set_markup(
+                self.place_field.EMPTY_TEXT)
+            self.place_field.set_button(False)
+
+
 #-------------------------------------------------------------------------
 #
 # Delete Query class
 #
 #-------------------------------------------------------------------------
-class DeleteEventQuery(object):
+class DeleteEventQuery:
     def __init__(self, dbstate, uistate, event, person_list, family_list):
         self.event = event
         self.db = dbstate.db
@@ -320,7 +338,7 @@ class DeleteEventQuery(object):
         with DbTxn(_("Delete Event (%s)") % self.event.get_gramps_id(),
                    self.db) as trans:
             self.db.disable_signals()
-        
+
             ev_handle_list = [self.event.get_handle()]
 
             for handle in self.person_list:
