@@ -158,32 +158,38 @@ class EditPlace(EditPrimary):
             self.obj.set_code, self.obj.get_code,
             self.db.readonly)
 
+        entry = self.top.get_object("lon_entry")
+        entry.set_ltr_mode()
         self.longitude = MonitoredEntry(
-            self.top.get_object("lon_entry"),
+            entry,
             self.obj.set_longitude, self.obj.get_longitude,
             self.db.readonly)
         self.longitude.connect("validate", self._validate_coordinate, "lon")
         #force validation now with initial entry
-        self.top.get_object("lon_entry").validate(force=True)
+        entry.validate(force=True)
 
+        entry = self.top.get_object("lat_entry")
+        entry.set_ltr_mode()
         self.latitude = MonitoredEntry(
-            self.top.get_object("lat_entry"),
+            entry,
             self.obj.set_latitude, self.obj.get_latitude,
             self.db.readonly)
         self.latitude.connect("validate", self._validate_coordinate, "lat")
         #force validation now with initial entry
-        self.top.get_object("lat_entry").validate(force=True)
+        entry.validate(force=True)
 
+        entry = self.top.get_object("latlon_entry")
+        entry.set_ltr_mode()
         self.latlon = MonitoredEntry(
-            self.top.get_object("latlon_entry"),
+            entry,
             self.set_latlongitude, self.get_latlongitude,
             self.db.readonly)
 
     def set_latlongitude(self, value):
         try:
             coma = value.index(',')
-            self.longitude.set_text(value[coma+1:])
-            self.latitude.set_text(value[:coma])
+            self.longitude.set_text(value[coma+1:].strip())
+            self.latitude.set_text(value[:coma].strip())
             self.top.get_object("lat_entry").validate(force=True)
             self.top.get_object("lon_entry").validate(force=True)
             self.obj.set_latitude(self.latitude.get_value())
@@ -355,7 +361,7 @@ class DeletePlaceQuery:
         self.obj = place
         self.person_list = person_list
         self.family_list = family_list
-        self.event_list  = event_list
+        self.event_list = event_list
 
     def query_response(self):
         place_title = place_displayer.display(self.db, self.obj)
