@@ -49,7 +49,7 @@ from gi.repository import GObject
 
 #-------------------------------------------------------------------------
 #
-# GRAMPS modules
+# Gramps modules
 #
 #-------------------------------------------------------------------------
 from gramps.gen.const import GRAMPS_LOCALE as glocale
@@ -67,7 +67,6 @@ from ..editors import EditPerson
 from ..glade import Glade
 from ..listmodel import ListModel, NOSORT, TOGGLE
 from gramps.gen.const import URL_WIKISTRING, USER_HOME, WIKI_EXTRAPLUGINS_RAWDATA
-from gramps.gen.constfunc import win, conv_to_unicode
 from gramps.gen.config import config
 from ..widgets.progressdialog import (LongOpStatus, ProgressMonitor,
                                       GtkProgressDialog)
@@ -78,6 +77,9 @@ def display_message(message):
     """
     print(message)
 
+RELOAD = 777    # A custom Gtk response_type for the Reload button
+
+
 #-------------------------------------------------------------------------
 #
 # PluginStatus: overview of all plugins
@@ -88,7 +90,7 @@ class PluginStatus(ManagedWindow):
     HIDDEN = '<span color="red">%s</span>' % _('Hidden')
     AVAILABLE = '<span weight="bold" color="blue">%s</span>'\
                                 % _('Visible')
-    
+
     def __init__(self, dbstate, uistate, track=[]):
         self.dbstate = dbstate
         self.__uistate = uistate
@@ -98,21 +100,22 @@ class PluginStatus(ManagedWindow):
 
         self.__pmgr = GuiPluginManager.get_instance()
         self.__preg = PluginRegister.get_instance()
-        self.set_window(Gtk.Dialog("", uistate.window,
-                                   Gtk.DialogFlags.DESTROY_WITH_PARENT,
-                                   (_('_Close'), Gtk.ResponseType.CLOSE)),
-                        None, self.title)
-        self.window.set_size_request(750, 400)
-        self.window.connect('response', self.close)
-        
+        dialog = Gtk.Dialog(title="", transient_for=uistate.window,
+                            destroy_with_parent=True)
+        dialog.add_button(_('_Close'), Gtk.ResponseType.CLOSE)
+        self.set_window(dialog, None, self.title)
+
+        self.setup_configs('interface.pluginstatus', 750, 400)
+        self.window.connect('response', self.__on_dialog_button)
+
         notebook = Gtk.Notebook()
-        
+
         #first page with all registered plugins
         vbox_reg = Gtk.Box(orientation=Gtk.Orientation.VERTICAL)
-        scrolled_window_reg =  Gtk.ScrolledWindow()
-        self.list_reg =  Gtk.TreeView()
+        scrolled_window_reg = Gtk.ScrolledWindow()
+        self.list_reg = Gtk.TreeView()
         #  model: plugintype, hidden, pluginname, plugindescr, pluginid
-        self.model_reg = Gtk.ListStore(GObject.TYPE_STRING, GObject.TYPE_STRING, 
+        self.model_reg = Gtk.ListStore(GObject.TYPE_STRING, GObject.TYPE_STRING,
                 GObject.TYPE_STRING, GObject.TYPE_STRING, GObject.TYPE_STRING)
         self.selection_reg = self.list_reg.get_selection()
         self.list_reg.set_model(self.model_reg)
@@ -143,7 +146,7 @@ class PluginStatus(ManagedWindow):
         self.__info_btn.connect('clicked', self.__info, self.list_reg, 4) # id_col
         self.__hide_btn = Gtk.Button(label=_("Hide/Unhide"))
         hbutbox.add(self.__hide_btn)
-        self.__hide_btn.connect('clicked', self.__hide, 
+        self.__hide_btn.connect('clicked', self.__hide,
                                 self.list_reg, 4, 1) # list, id_col, hide_col
         if __debug__:
             self.__edit_btn = Gtk.Button(label=_("Edit"))
@@ -153,16 +156,16 @@ class PluginStatus(ManagedWindow):
             hbutbox.add(self.__load_btn)
             self.__load_btn.connect('clicked', self.__load, self.list_reg, 4) # id_col
         vbox_reg.pack_start(hbutbox, False, False, 0)
-        
-        notebook.append_page(vbox_reg, 
+
+        notebook.append_page(vbox_reg,
                              tab_label=Gtk.Label(label=_('Registered Plugins')))
-        
+
         #second page with loaded plugins
         vbox_loaded = Gtk.Box(orientation=Gtk.Orientation.VERTICAL)
         scrolled_window = Gtk.ScrolledWindow()
         self.list = Gtk.TreeView()
-        self.model = Gtk.ListStore(GObject.TYPE_STRING, GObject.TYPE_STRING, 
-                                   GObject.TYPE_STRING, object, 
+        self.model = Gtk.ListStore(GObject.TYPE_STRING, GObject.TYPE_STRING,
+                                   GObject.TYPE_STRING, object,
                                    GObject.TYPE_STRING, GObject.TYPE_STRING)
         self.selection = self.list.get_selection()
         self.list.set_model(self.model)
@@ -173,12 +176,12 @@ class PluginStatus(ManagedWindow):
         col.set_sort_column_id(0)
         col.set_resizable(True)
         self.list.append_column(col)
-        col1 = Gtk.TreeViewColumn(_('File'), Gtk.CellRendererText(), 
+        col1 = Gtk.TreeViewColumn(_('File'), Gtk.CellRendererText(),
                                   text=1)
         col1.set_sort_column_id(1)
         col1.set_resizable(True)
         self.list.append_column(col1)
-        col = Gtk.TreeViewColumn(_('Status'), Gtk.CellRendererText(), 
+        col = Gtk.TreeViewColumn(_('Status'), Gtk.CellRendererText(),
                                  markup=5)
         col.set_sort_column_id(5)
         self.list.append_column(col)
@@ -209,7 +212,7 @@ class PluginStatus(ManagedWindow):
             hbutbox.add(self.__load_btn)
             self.__load_btn.connect('clicked', self.__load, self.list, 4) # id_col
         vbox_loaded.pack_start(hbutbox, False, False, 5)
-        notebook.append_page(vbox_loaded, 
+        notebook.append_page(vbox_loaded,
                              tab_label=Gtk.Label(label=_('Loaded Plugins')))
 
         #third page with method to install plugin
@@ -217,15 +220,15 @@ class PluginStatus(ManagedWindow):
         scrolled_window = Gtk.ScrolledWindow()
         self.addon_list = Gtk.TreeView()
         # model: help_name, name, ptype, image, desc, use, rating, contact, download, url
-        self.addon_model = Gtk.ListStore(GObject.TYPE_STRING, 
-                                         GObject.TYPE_STRING, 
-                                         GObject.TYPE_STRING, 
-                                         GObject.TYPE_STRING, 
-                                         GObject.TYPE_STRING, 
-                                         GObject.TYPE_STRING, 
-                                         GObject.TYPE_STRING, 
-                                         GObject.TYPE_STRING, 
-                                         GObject.TYPE_STRING, 
+        self.addon_model = Gtk.ListStore(GObject.TYPE_STRING,
+                                         GObject.TYPE_STRING,
+                                         GObject.TYPE_STRING,
+                                         GObject.TYPE_STRING,
+                                         GObject.TYPE_STRING,
+                                         GObject.TYPE_STRING,
+                                         GObject.TYPE_STRING,
+                                         GObject.TYPE_STRING,
+                                         GObject.TYPE_STRING,
                                          GObject.TYPE_STRING)
         self.addon_list.set_model(self.addon_model)
         #self.addon_list.connect('button-press-event', self.button_press)
@@ -269,31 +272,35 @@ class PluginStatus(ManagedWindow):
         self.__add_btn.connect('clicked', self.__get_addon_top)
         self.__add_all_btn = Gtk.Button(label=_("Install All Addons"))
         hbutbox.add(self.__add_all_btn)
-        self.__add_all_btn.connect('clicked', self.__get_all_addons) 
+        self.__add_all_btn.connect('clicked', self.__get_all_addons)
         self.__refresh_btn = Gtk.Button(label=_("Refresh Addon List"))
         hbutbox.add(self.__refresh_btn)
-        self.__refresh_btn.connect('clicked', self.__refresh_addon_list) 
+        self.__refresh_btn.connect('clicked', self.__refresh_addon_list)
         install_page.pack_start(hbutbox, False, True, 5)
-        # notebook.append_page(install_page, 
+        # notebook.append_page(install_page,
         #                      tab_label=Gtk.Label(label=_('Install Addons')))
 
         #add the notebook to the window
         self.window.get_content_area().pack_start(notebook, True, True, 0)
-        
+
         if __debug__:
-            # Only show the "Reload" button when in debug mode 
+            # Only show the "Reload" button when in debug mode
             # (without -O on the command line)
-            self.__reload_btn = Gtk.Button(label=_("Reload"))
-            self.window.action_area.add(self.__reload_btn)
-            self.__reload_btn.connect('clicked', self.__reload)
-        
+            self.window.add_button(_("Reload"), RELOAD)
+
         #obtain hidden plugins from the pluginmanager
         self.hidden = self.__pmgr.get_hidden_plugin_ids()
-        
+
         self.window.show_all()
         self.__populate_lists()
         self.list_reg.columns_autosize()
 
+    def __on_dialog_button(self, dialog, response_id):
+        if response_id == Gtk.ResponseType.CLOSE:
+            self.close(dialog)
+        else:   # response_id == RELOAD
+            self.__reload(dialog)
+
     def __refresh_addon_list(self, obj):
         """
         Reloads the addons from the wiki into the list.
@@ -306,7 +313,8 @@ class PluginStatus(ManagedWindow):
         except:
             print("Error: cannot open %s" % URL)
             return
-        pm = ProgressMeter(_("Refreshing Addon List"))
+        pm = ProgressMeter(_("Refreshing Addon List"),
+                           parent=self.uistate.window)
         pm.set_pass(header=_("Reading gramps-project.org..."))
         state = "read"
         rows = []
@@ -356,7 +364,7 @@ class PluginStatus(ManagedWindow):
                 if "|" in url:
                     url, text = url.split("|", 1)
                 # need to get a page that says where it is:
-                fp = urlopen("%s%s%s" % (URL_WIKISTRING, url, 
+                fp = urlopen("%s%s%s" % (URL_WIKISTRING, url,
                                 "&action=edit&externaledit=true&mode=file"))
                 for line in fp:
                     if line.startswith("URL="):
@@ -367,14 +375,14 @@ class PluginStatus(ManagedWindow):
                 url = download[1:-1]
                 if " " in url:
                     url, text = url.split(" ", 1)
-            if (url.endswith(".zip") or 
-                url.endswith(".ZIP") or 
-                url.endswith(".tar.gz") or 
+            if (url.endswith(".zip") or
+                url.endswith(".ZIP") or
+                url.endswith(".tar.gz") or
                 url.endswith(".tgz")):
                 # Then this is ok:
-                self.addon_model.append(row=[help_name, name, ptype, image, desc, use, 
+                self.addon_model.append(row=[help_name, name, ptype, image, desc, use,
                                              rating, contact, download, url])
-                config.get('plugin.addonplugins').append([help_name, name, ptype, image, desc, use, 
+                config.get('plugin.addonplugins').append([help_name, name, ptype, image, desc, use,
                                                           rating, contact, download, url])
         pm.close()
         config.save()
@@ -384,12 +392,14 @@ class PluginStatus(ManagedWindow):
         Get all addons from the wiki and install them.
         """
         from ..utils import ProgressMeter
-        pm = ProgressMeter(_("Install all Addons"), _("Installing..."), message_area=True)
+        pm = ProgressMeter(
+            _("Install all Addons"), _("Installing..."), message_area=True,
+            parent=self.uistate.window)
         pm.set_pass(total=len(self.addon_model))
         errors = []
         for row in self.addon_model:
             pm.step()
-            (help_name, name, ptype, image, desc, use, rating, contact, 
+            (help_name, name, ptype, image, desc, use, rating, contact,
              download, url) = row
             load_addon_file(url, callback=pm.append_message)
         self.uistate.viewmanager.do_reg_plugins(self.dbstate, self.uistate)
@@ -402,7 +412,9 @@ class PluginStatus(ManagedWindow):
         Toplevel method to get an addon.
         """
         from ..utils import ProgressMeter
-        pm = ProgressMeter(_("Installing Addon"), message_area=True)
+        pm = ProgressMeter(
+            _("Installing Addon"), message_area=True,
+            parent=self.uistate.window)
         pm.set_pass(total=2, header=_("Reading gramps-project.org..."))
         pm.step()
         self.__get_addon(obj, callback=pm.append_message)
@@ -423,7 +435,8 @@ class PluginStatus(ManagedWindow):
         """
         Select a file from the file system.
         """
-        fcd = Gtk.FileChooserDialog(_("Load Addon"), 
+        fcd = Gtk.FileChooserDialog(_("Load Addon"),
+                                    parent=self.__uistate.window,
                                     buttons=(_('_Cancel'),
                                              Gtk.ResponseType.CANCEL,
                                              _('_Open'),
@@ -441,7 +454,7 @@ class PluginStatus(ManagedWindow):
 
         status = fcd.run()
         if status == Gtk.ResponseType.OK:
-            path = conv_to_unicode(fcd.get_filename())
+            path = fcd.get_filename()
             if path:
                 self.install_addon_path.set_text(path)
         fcd.destroy()
@@ -462,13 +475,13 @@ class PluginStatus(ManagedWindow):
                 help_name, name, ptype, image, desc, use, rating, contact, download, url = row
             except:
                 continue
-            self.addon_model.append(row=[help_name, name, ptype, image, desc, use, 
+            self.addon_model.append(row=[help_name, name, ptype, image, desc, use,
                                          rating, contact, download, url])
 
     def __populate_load_list(self):
         """ Build list of loaded plugins"""
         fail_list = self.__pmgr.get_fail_list()
-        
+
         for i in fail_list:
             # i = (filename, (exception-type, exception, traceback), pdata)
             err = i[1][0]
@@ -501,7 +514,7 @@ class PluginStatus(ManagedWindow):
             self.model.append(row=[
                 '<span weight="bold" color="#267726">%s</span>' % _("OK"),
                 i[0], pdata.description, None, pdata.id, hiddenstr])
-        
+
     def __populate_reg_list(self):
         """ Build list of registered plugins"""
         for (type, typestr) in PTYPE_STR.items():
@@ -521,7 +534,7 @@ class PluginStatus(ManagedWindow):
     def __rebuild_load_list(self):
         self.model.clear()
         self.__populate_load_list()
-    
+
     def __rebuild_reg_list(self):
         self.model_reg.clear()
         self.__populate_reg_list()
@@ -537,19 +550,21 @@ class PluginStatus(ManagedWindow):
 
     def button_press(self, obj, event):
         """ Callback function from the user clicking on a line """
-        if event.type == Gdk.EventType._2BUTTON_PRESS and event.button == 1:
+        if (event.type == Gdk.EventType.DOUBLE_BUTTON_PRESS
+                and event.button == 1):
             model, node = self.selection.get_selected()
             data = model.get_value(node, 3)
             name = model.get_value(node, 1)
             if data:
                 PluginTrace(self.uistate, [], data, name)
-                
+
     def button_press_reg(self, obj, event):
         """ Callback function from the user clicking on a line in reg plugin
         """
-        if event.type == Gdk.EventType._2BUTTON_PRESS and event.button == 1:
+        if (event.type == Gdk.EventType.DOUBLE_BUTTON_PRESS
+                and event.button == 1):
             self.__info(obj, self.list_reg, 4)
-    
+
     def button_press_addon(self, obj):
         """ Callback function from the user clicking on a line in reg plugin
         """
@@ -559,16 +574,16 @@ class PluginStatus(ManagedWindow):
             if node:
                 url = model.get_value(node, 9)
                 self.install_addon_path.set_text(url)
-    
+
     def build_menu_names(self, obj):
         return (self.title, "")
-    
+
     def __reload(self, obj):
         """ Callback function from the "Reload" button """
         self.__pmgr.reload_plugins()
         self.__rebuild_load_list()
         self.__rebuild_reg_list()
-    
+
     def __info(self, obj, list_obj, id_col):
         """ Callback function from the "Info" button
         """
@@ -581,9 +596,9 @@ class PluginStatus(ManagedWindow):
         typestr = pdata.ptype
         auth = ' - '.join(pdata.authors)
         email = ' - '.join(pdata.authors_email)
-        if len(auth) > 60: 
+        if len(auth) > 60:
             auth = auth[:60] + '...'
-        if len(email) > 60: 
+        if len(email) > 60:
             email = email[:60] + '...'
         if pdata:
             infotxt = """%(plugnam)s: %(name)s [%(typestr)s]
@@ -611,8 +626,9 @@ class PluginStatus(ManagedWindow):
             'plugfil': _("Filename"),
             'plugpat': _("Location"),
             }
-            InfoDialog(_('Detailed Info'), infotxt, parent=self.window)
-    
+            InfoDialog(_('Detailed Info'), infotxt,
+                       parent=self.window)
+
     def __hide(self, obj, list_obj, id_col, hide_col):
         """ Callback function from the "Hide" button
         """
@@ -631,7 +647,7 @@ class PluginStatus(ManagedWindow):
             self.hidden.add(id)
             model.set_value(node, hide_col, self.HIDDEN)
             self.__pmgr.hide_plugin(id)
-    
+
     def __load(self, obj, list_obj, id_col):
         """ Callback function from the "Load" button
         """
@@ -655,8 +671,8 @@ class PluginStatus(ManagedWindow):
         pdata = self.__preg.get_plugin(id)
         if pdata.fpath and pdata.fname:
             open_file_with_default_application(
-                os.path.join(pdata.fpath, pdata.fname)
-                )
+                os.path.join(pdata.fpath, pdata.fname),
+                self.uistate)
 
 #-------------------------------------------------------------------------
 #
@@ -665,19 +681,20 @@ class PluginStatus(ManagedWindow):
 #-------------------------------------------------------------------------
 class PluginTrace(ManagedWindow):
     """Displays a dialog showing the status of loaded plugins"""
-    
+
     def __init__(self, uistate, track, data, name):
         self.name = name
-        title = "%s: %s" % (_("Plugin Error"), name)
+        title = _("%(str1)s: %(str2)s"
+                 ) % {'str1': _("Plugin Error"), 'str2': name}
         ManagedWindow.__init__(self, uistate, track, self)
 
         self.set_window(Gtk.Dialog("", uistate.window,
                                    Gtk.DialogFlags.DESTROY_WITH_PARENT,
                                    (_('_Close'), Gtk.ResponseType.CLOSE)),
                         None, title)
-        self.window.set_size_request(600, 400)
+        self.setup_configs('interface.plugintrace', 600, 400)
         self.window.connect('response', self.close)
-        
+
         scrolled_window = Gtk.ScrolledWindow()
         scrolled_window.set_policy(Gtk.PolicyType.AUTOMATIC, Gtk.PolicyType.AUTOMATIC)
         self.text = Gtk.TextView()
@@ -699,7 +716,7 @@ class PluginTrace(ManagedWindow):
 #-------------------------------------------------------------------------
 class LinkTag(Gtk.TextTag):
     def __init__(self, link, buffer):
-        GObject.GObject.__init__(self, name=link)
+        Gtk.TextTag.__init__(self, name=link)
         tag_table = buffer.get_tag_table()
         self.set_property('foreground', "#0000ff")
         self.set_property('underline', Pango.Underline.SINGLE)
@@ -748,19 +765,23 @@ class ToolManagedWindowBase(ManagedWindow):
         # Build the list of widgets that are used to extend the Options
         # frame and to create other frames
         self.add_user_options()
-        
+
         self.notebook = Gtk.Notebook()
         self.notebook.set_border_width(6)
-        self.window.get_content_area().add(self.notebook)
+        self.window.get_content_area().pack_start(self.notebook, True, True, 0)
 
-        self.results_text = Gtk.TextView() 
-        self.results_text.connect('button-press-event', 
-                                  self.on_button_press) 
-        self.results_text.connect('motion-notify-event', 
+        self.results_text = Gtk.TextView()
+        self.results_text.connect('button-press-event',
+                                  self.on_button_press)
+        self.results_text.connect('motion-notify-event',
                                   self.on_motion)
         self.tags = []
-        self.link_cursor = Gdk.Cursor.new(Gdk.CursorType.LEFT_PTR)
-        self.standard_cursor = Gdk.Cursor.new(Gdk.CursorType.XTERM)
+        self.link_cursor = \
+            Gdk.Cursor.new_for_display(Gdk.Display.get_default(),
+                                       Gdk.CursorType.LEFT_PTR)
+        self.standard_cursor = \
+            Gdk.Cursor.new_for_display(Gdk.Display.get_default(),
+                                       Gdk.CursorType.XTERM)
 
         self.setup_other_frames()
         self.set_current_frame(self.initial_frame())
@@ -790,8 +811,8 @@ class ToolManagedWindowBase(ManagedWindow):
         return None
 
     def on_motion(self, view, event):
-        buffer_location = view.window_to_buffer_coords(Gtk.TextWindowType.TEXT, 
-                                                       int(event.x), 
+        buffer_location = view.window_to_buffer_coords(Gtk.TextWindowType.TEXT,
+                                                       int(event.x),
                                                        int(event.y))
         iter = view.get_iter_at_location(*buffer_location)
         for (tag, person_handle) in self.tags:
@@ -803,15 +824,15 @@ class ToolManagedWindowBase(ManagedWindow):
         return False # handle event further, if necessary
 
     def on_button_press(self, view, event):
-        buffer_location = view.window_to_buffer_coords(Gtk.TextWindowType.TEXT, 
-                                                       int(event.x), 
+        buffer_location = view.window_to_buffer_coords(Gtk.TextWindowType.TEXT,
+                                                       int(event.x),
                                                        int(event.y))
         iter = view.get_iter_at_location(*buffer_location)
         for (tag, person_handle) in self.tags:
             if iter.has_tag(tag):
                 person = self.db.get_person_from_handle(person_handle)
                 if event.button == 1:
-                    if event.type == Gdk.EventType._2BUTTON_PRESS:
+                    if event.type == Gdk.EventType.DOUBLE_BUTTON_PRESS:
                         try:
                             EditPerson(self.dbstate, self.uistate, [], person)
                         except WindowActiveError:
@@ -831,20 +852,20 @@ class ToolManagedWindowBase(ManagedWindow):
         end = buffer.get_end_iter()
         self.tags.append((LinkTag(person_handle, buffer), person_handle))
         buffer.apply_tag(self.tags[-1][0], start, end)
-        
+
     def results_write(self, text):
         buffer = self.results_text.get_buffer()
         mark = buffer.create_mark("end", buffer.get_end_iter())
         self.results_text.scroll_to_mark(mark, 0.0, True, 0, 0)
         buffer.insert_at_cursor(text)
-        buffer.delete_mark_by_name("end")        
+        buffer.delete_mark_by_name("end")
 
     def write_to_page(self, page, text):
         buffer = page.get_buffer()
         mark = buffer.create_mark("end", buffer.get_end_iter())
         page.scroll_to_mark(mark, 0.0, True, 0, 0)
         buffer.insert_at_cursor(text)
-        buffer.delete_mark_by_name("end")        
+        buffer.delete_mark_by_name("end")
 
     def clear(self, text):
         # Remove all tags and clear text
@@ -869,11 +890,12 @@ class ToolManagedWindowBase(ManagedWindow):
             tag_table.remove(tag)
         self.tags = []
         buffer.set_text("")
-        
+
     def pre_run(self):
         from ..utils import ProgressMeter
-        self.progress = ProgressMeter(self.get_title())
-        
+        self.progress = ProgressMeter(self.get_title(),
+                                      parent=self.window)
+
     def run(self):
         raise NotImplementedError("tool needs to define a run() method")
 
@@ -896,7 +918,7 @@ class ToolManagedWindowBase(ManagedWindow):
         some indication of what the report will be, i.e. 'Descendant
         Report for %s'."""
         return self.get_title()
-        
+
     def setup_title(self):
         """Set up the title bar of the dialog.  This function relies
         on the get_title() customization function for what the title
@@ -913,7 +935,7 @@ class ToolManagedWindowBase(ManagedWindow):
         title = self.get_header(self.get_title())
         label = Gtk.Label(label='<span size="larger" weight="bold">%s</span>' % title)
         label.set_use_markup(True)
-        self.window.get_content_area().pack_start(label, False, False, 
+        self.window.get_content_area().pack_start(label, False, False,
                                                   self.border_pad)
 
     def add_frame_option(self, frame_name, label_text, widget):
@@ -925,7 +947,7 @@ class ToolManagedWindowBase(ManagedWindow):
         all managing of the widgets, including extracting the final value
         before the report executes. This task should only be called in
         the add_user_options task."""
-        
+
         if frame_name in self.frames:
             self.frames[frame_name].append((label_text, widget))
         else:
@@ -950,7 +972,7 @@ class ToolManagedWindowBase(ManagedWindow):
             window.set_policy(Gtk.PolicyType.AUTOMATIC, Gtk.PolicyType.AUTOMATIC)
             window.add(self.results_text)
             window.set_shadow_type(Gtk.ShadowType.IN)
-            self.frames[frame_name] = [[frame_name, window]] 
+            self.frames[frame_name] = [[frame_name, window]]
             self.frame_names.append(frame_name)
             l = Gtk.Label(label="<b>%s</b>" % _(frame_name))
             l.set_use_markup(True)
@@ -962,13 +984,13 @@ class ToolManagedWindowBase(ManagedWindow):
 
     def add_page(self, frame_name="Help"):
         if frame_name not in self.frames:
-            text = Gtk.TextView() 
+            text = Gtk.TextView()
             text.set_wrap_mode(Gtk.WrapMode.WORD)
             window = Gtk.ScrolledWindow()
             window.set_policy(Gtk.PolicyType.AUTOMATIC, Gtk.PolicyType.AUTOMATIC)
             window.add(text)
             window.set_shadow_type(Gtk.ShadowType.IN)
-            self.frames[frame_name] = [[frame_name, window]] 
+            self.frames[frame_name] = [[frame_name, window]]
             self.frame_names.append(frame_name)
             l = Gtk.Label(label="<b>%s</b>" % _(frame_name))
             l.set_use_markup(True)
@@ -1036,7 +1058,7 @@ class ToolManagedWindowBatch(tool.BatchTool, ToolManagedWindowBase):
         self.uistate = uistate
         tool.BatchTool.__init__(self, dbstate, user, options_class, name)
         if not self.fail:
-            ToolManagedWindowBase.__init__(self, dbstate, uistate, 
+            ToolManagedWindowBase.__init__(self, dbstate, uistate,
                                            options_class, name, callback)
 
 class ToolManagedWindow(tool.Tool, ToolManagedWindowBase):
@@ -1044,7 +1066,7 @@ class ToolManagedWindow(tool.Tool, ToolManagedWindowBase):
         self.dbstate = dbstate
         self.uistate = uistate
         tool.Tool.__init__(self, dbstate, options_class, name)
-        ToolManagedWindowBase.__init__(self, dbstate, uistate, options_class, 
+        ToolManagedWindowBase.__init__(self, dbstate, uistate, options_class,
                                        name, callback)
 
 #-------------------------------------------------------------------------
@@ -1052,16 +1074,17 @@ class ToolManagedWindow(tool.Tool, ToolManagedWindowBase):
 # UpdateAddons
 #
 #-------------------------------------------------------------------------
-class UpdateAddons():
+class UpdateAddons(ManagedWindow):
 
-    def __init__(self, addon_update_list, parent_window):
+    def __init__(self, uistate, track, addon_update_list):
         self.title = _('Available Gramps Updates for Addons')
 
+        ManagedWindow.__init__(self, uistate, track, self, modal=True)
         glade = Glade("updateaddons.glade")
-        self.window = glade.toplevel
+        self.set_window(glade.toplevel, None, None)
         self.window.set_title(self.title)
-        self.window.set_size_request(750, 400)
-        self.window.set_transient_for(parent_window)
+        self.setup_configs("interface.updateaddons", 750, 400)
+        self.rescan = False
 
         apply_button = glade.get_object('apply')
         cancel_button = glade.get_object('cancel')
@@ -1091,9 +1114,9 @@ class UpdateAddons():
         last_category = None
         for (status,plugin_url,plugin_dict) in addon_update_list:
             count = get_count(addon_update_list, plugin_dict["t"])
-            category = _("%(adjective)s: %(addon)s") % {
-                "adjective": status, 
-                "addon": _(plugin_dict["t"])}
+            # translators: needed for French, ignore otherwise
+            category = _("%(str1)s: %(str2)s") % {'str1' : status,
+                                                  'str2' : _(plugin_dict["t"])}
             if last_category != category:
                 last_category = category
                 node = self.list.add([False, # initially selected?
@@ -1115,13 +1138,12 @@ class UpdateAddons():
                 pos = iter
         if pos:
             self.list.selection.select_iter(pos)
+
+        self.show()
         self.window.run()
 
-    def close(self, widget):
-        """
-        Close the dialog.
-        """
-        self.window.destroy()
+    def build_menu_names(self, obj):
+        return (self.title, " ")
 
     def select_all_clicked(self, widget):
         """
@@ -1156,12 +1178,12 @@ class UpdateAddons():
             length, 1, # total, increment-by
             can_cancel=True)
         pm = ProgressMonitor(GtkProgressDialog,
-                             ("Title", self.window, Gtk.DialogFlags.MODAL))
+                             ("Title", self.parent_window, Gtk.DialogFlags.MODAL))
         pm.add_op(longop)
         count = 0
-        if not config.get('behavior.do-not-show-previously-seen-updates'):
+        if not config.get('behavior.do-not-show-previously-seen-addon-updates'):
             # reset list
-            config.get('behavior.previously-seen-updates')[:] = []
+            config.get('behavior.previously-seen-addon-updates')[:] = []
 
         iter = model.get_iter_first()
         errors = []
@@ -1178,8 +1200,8 @@ class UpdateAddons():
                     else:
                         errors.append(row[2])
                 else: # add to list of previously seen, but not installed
-                    if row[5] not in config.get('behavior.previously-seen-updates'):
-                        config.get('behavior.previously-seen-updates').append(row[5])
+                    if row[5] not in config.get('behavior.previously-seen-addon-updates'):
+                        config.get('behavior.previously-seen-addon-updates').append(row[5])
                 longop.heartbeat()
                 pm._get_dlg()._process_events()
             iter = model.iter_next(iter)
@@ -1189,21 +1211,23 @@ class UpdateAddons():
         if errors:
             OkDialog(_("Installation Errors"),
                      _("The following addons had errors: ") +
+                     # TODO for Arabic, should the next comma be translated?
                      ", ".join(errors),
-                     self.window)
+                     parent=self.parent_window)
         if count:
+            self.rescan = True
             OkDialog(_("Done downloading and installing addons"),
                      # translators: leave all/any {...} untranslated
                      "%s %s" % (ngettext("{number_of} addon was installed.",
                                          "{number_of} addons were installed.",
                                          count).format(number_of=count),
-                                _("You need to restart Gramps to see new views.")),
-                     self.window)
+                        _("If you have installed a 'Gramps View', you will need to restart Gramps.")),
+                     parent=self.parent_window)
         else:
             OkDialog(_("Done downloading and installing addons"),
                      _("No addons were installed."),
-                     self.window)
-        self.window.destroy()
+                     parent=self.parent_window)
+        self.close()
 
 #-------------------------------------------------------------------------
 #
