@@ -29,13 +29,7 @@ Provide a simplified table creation interface
 # Standard python modules
 #
 #-------------------------------------------------------------------------
-from __future__ import print_function
-
-import sys
-if sys.version_info[0] < 3:
-    import cPickle as pickle
-else:
-    import pickle
+import pickle
 
 #-------------------------------------------------------------------------
 #
@@ -51,15 +45,15 @@ from gi.repository import Gtk
 #
 #-------------------------------------------------------------------------
 from gramps.gen.const import GRAMPS_LOCALE as glocale
-from gramps.gen.const import GRAMPS_LOCALE as glocale
 _ = glocale.translation.sgettext
 from gramps.gen.simple import SimpleTable
 from gramps.gen.errors import WindowActiveError
+from ...utils import model_to_text, text_to_clipboard
 from ...widgets.multitreeview import MultiTreeView
 from ...ddtargets import DdTargets
 from ..quick import run_quick_report_by_name
-from ...editors import (EditPerson, EditEvent, EditFamily, EditCitation, 
-                         EditSource, EditPlace, EditRepository, EditNote, 
+from ...editors import (EditPerson, EditEvent, EditFamily, EditCitation,
+                         EditSource, EditPlace, EditRepository, EditNote,
                          EditMedia)
 
 #-------------------------------------------------------------------------
@@ -81,6 +75,12 @@ class QuickTable(SimpleTable):
             self._callback_leftdouble = callback
 
     def button_press_event(self, treeview, event):
+        wid = treeview.get_toplevel()
+        try:
+            winmgr = self.simpledoc.doc.uistate.gwm
+            self.track = winmgr.get_item_from_window(wid).track
+        except:
+            self.track = []
         index = None
         button_code = None
         event_time = None
@@ -94,11 +94,11 @@ class QuickTable(SimpleTable):
             node = store.get_iter(tpath) if tpath else None
             if node:
                 treeview.grab_focus()
-                index = store.get_value(node, 0) 
+                index = store.get_value(node, 0)
                 # FIXME: make popup come where cursor is
                 #rectangle = treeview.get_visible_rect()
                 #column = treeview.get_column(0)
-                #rectangle = treeview.get_cell_area("0:0", 
+                #rectangle = treeview.get_cell_area("0:0",
                 #x, y = rectangle.x, rectangle.y
                 #func = lambda menu: (x, y, True)
         elif event.button == 3:
@@ -118,53 +118,63 @@ class QuickTable(SimpleTable):
                     treeview.grab_focus()
                     treeview.set_cursor(path, col, 0)
                 if store and node:
-                    index = store.get_value(node, 0) # index Below,
+                    index = store.get_value(node, 0)  # index Below,
         # you need index, treeview, path, button_code,
         # func, and event_time
         if index is not None:
+            if self._link[index]:
+                objclass, handle = self._link[index]
+            else:
+                return False
+            if (self.simpledoc.doc.uistate.get_export_mode() and
+                    objclass != 'Filter'):
+                return False  # avoid edition during export
             self.popup = Gtk.Menu()
             popup = self.popup
-            if (index is not None and self._link[index]):
+            menu_item = Gtk.MenuItem(label=_("Copy all"))
+            menu_item.connect("activate", lambda widget: text_to_clipboard(
+                              model_to_text(treeview.get_model())))
+            popup.append(menu_item)
+            menu_item.show()
+            # Now add more items to popup menu, if available
             # See details (edit, etc):
-                objclass, handle = self._link[index]
-                menu_item = Gtk.MenuItem(label=_("the object|See %s details") % glocale.trans_objclass(objclass))
-                menu_item.connect("activate", 
-                  lambda widget: self.on_table_doubleclick(treeview))
+            menu_item = Gtk.MenuItem(label=_("the object|See %s details") %
+                                     glocale.trans_objclass(objclass))
+            menu_item.connect(
+                "activate", lambda widget: self.on_table_doubleclick(treeview))
+            popup.append(menu_item)
+            menu_item.show()
+            # Add other items to menu:
+            if objclass == 'Person':
+                menu_item = Gtk.MenuItem(label=_("the object|Make %s active")
+                                         % glocale.trans_objclass('Person'))
+                menu_item.connect("activate",
+                                  lambda widget: self.on_table_click(treeview))
                 popup.append(menu_item)
                 menu_item.show()
-            # Add other items to menu:
-            if (self._callback_leftclick or 
-                (index is not None and self._link[index])):
-                objclass, handle = self._link[index]
-                if objclass == 'Person':
-                    menu_item = Gtk.MenuItem(label=_("the object|Make %s active") % glocale.trans_objclass('Person'))
-                    menu_item.connect("activate", 
-                      lambda widget: self.on_table_click(treeview))
-                    popup.append(menu_item)
-                    menu_item.show()
-            if (self.simpledoc.doc.dbstate.db != 
-                self.simpledoc.doc.dbstate.db.basedb and
-                (index is not None and self._link[index])):
-                objclass, handle = self._link[index]
-                if (objclass == 'Filter' and 
+            if (self.simpledoc.doc.dbstate.db !=
+                    self.simpledoc.doc.dbstate.db.basedb):
+                if (objclass == 'Filter' and
                     handle[0] in ['Person', 'Family', 'Place', 'Event',
-                                  'Repository', 'Note', 'MediaObject',
+                                  'Repository', 'Note', 'Media',
                                   'Citation', 'Source']):
                     menu_item = Gtk.MenuItem(label=_("See data not in Filter"))
-                    menu_item.connect("activate", 
-                      lambda widget: self.show_not_in_filter(handle[0]))
+                    menu_item.connect(
+                        "activate",
+                        lambda widget: self.show_not_in_filter(handle[0]))
                     popup.append(menu_item)
                     menu_item.show()
             # Show the popup menu:
             popup.popup(None, None, func, None, button_code, event_time)
-            return True        
+            return True
         return False
 
     def show_not_in_filter(self, obj_class):
         run_quick_report_by_name(self.simpledoc.doc.dbstate,
-                                 self.simpledoc.doc.uistate, 
-                                 'filterbyname', 
-                                 'Inverse %s' % obj_class)
+                                 self.simpledoc.doc.uistate,
+                                 'filterbyname',
+                                 'Inverse %s' % obj_class,
+                                 track=self.track)
 
     def on_table_doubleclick(self, obj):
         """
@@ -188,7 +198,7 @@ class QuickTable(SimpleTable):
                 person = self.access.dbase.get_person_from_handle(handle)
                 if person:
                     try:
-                        EditPerson(self.simpledoc.doc.dbstate, 
+                        EditPerson(self.simpledoc.doc.dbstate,
                                    self.simpledoc.doc.uistate, [], person)
                         return True # handled event
                     except WindowActiveError:
@@ -197,7 +207,7 @@ class QuickTable(SimpleTable):
                 event = self.access.dbase.get_event_from_handle(handle)
                 if event:
                     try:
-                        EditEvent(self.simpledoc.doc.dbstate, 
+                        EditEvent(self.simpledoc.doc.dbstate,
                                   self.simpledoc.doc.uistate, [], event)
                         return True # handled event
                     except WindowActiveError:
@@ -206,7 +216,7 @@ class QuickTable(SimpleTable):
                 ref = self.access.dbase.get_family_from_handle(handle)
                 if ref:
                     try:
-                        EditFamily(self.simpledoc.doc.dbstate, 
+                        EditFamily(self.simpledoc.doc.dbstate,
                                    self.simpledoc.doc.uistate, [], ref)
                         return True # handled event
                     except WindowActiveError:
@@ -215,7 +225,7 @@ class QuickTable(SimpleTable):
                 ref = self.access.dbase.get_citation_from_handle(handle)
                 if ref:
                     try:
-                        EditCitation(self.simpledoc.doc.dbstate, 
+                        EditCitation(self.simpledoc.doc.dbstate,
                                      self.simpledoc.doc.uistate, [], ref)
                         return True # handled event
                     except WindowActiveError:
@@ -224,7 +234,7 @@ class QuickTable(SimpleTable):
                 ref = self.access.dbase.get_source_from_handle(handle)
                 if ref:
                     try:
-                        EditSource(self.simpledoc.doc.dbstate, 
+                        EditSource(self.simpledoc.doc.dbstate,
                                    self.simpledoc.doc.uistate, [], ref)
                         return True # handled event
                     except WindowActiveError:
@@ -233,7 +243,7 @@ class QuickTable(SimpleTable):
                 ref = self.access.dbase.get_place_from_handle(handle)
                 if ref:
                     try:
-                        EditPlace(self.simpledoc.doc.dbstate, 
+                        EditPlace(self.simpledoc.doc.dbstate,
                                    self.simpledoc.doc.uistate, [], ref)
                         return True # handled event
                     except WindowActiveError:
@@ -242,7 +252,7 @@ class QuickTable(SimpleTable):
                 ref = self.access.dbase.get_repository_from_handle(handle)
                 if ref:
                     try:
-                        EditRepository(self.simpledoc.doc.dbstate, 
+                        EditRepository(self.simpledoc.doc.dbstate,
                                    self.simpledoc.doc.uistate, [], ref)
                         return True # handled event
                     except WindowActiveError:
@@ -251,33 +261,34 @@ class QuickTable(SimpleTable):
                 ref = self.access.dbase.get_note_from_handle(handle)
                 if ref:
                     try:
-                        EditNote(self.simpledoc.doc.dbstate, 
+                        EditNote(self.simpledoc.doc.dbstate,
                                  self.simpledoc.doc.uistate, [], ref)
                         return True # handled event
                     except WindowActiveError:
                         pass
-            elif objclass in ['Media', 'MediaObject']:
-                ref = self.access.dbase.get_object_from_handle(handle)
+            elif objclass == 'Media':
+                ref = self.access.dbase.get_media_from_handle(handle)
                 if ref:
                     try:
-                        EditMedia(self.simpledoc.doc.dbstate, 
+                        EditMedia(self.simpledoc.doc.dbstate,
                                   self.simpledoc.doc.uistate, [], ref)
                         return True # handled event
                     except WindowActiveError:
                         pass
             elif objclass == 'PersonList':
                 run_quick_report_by_name(self.simpledoc.doc.dbstate,
-                                         self.simpledoc.doc.uistate, 
-                                         'filterbyname', 
+                                         self.simpledoc.doc.uistate,
+                                         'filterbyname',
                                          'list of people',
-                                         handles=handle)
+                                         handle=handle,
+                                         track=self.track)
             elif objclass == 'Filter':
                 if isinstance(handle, list):
                     handle = handle[0]
                 run_quick_report_by_name(self.simpledoc.doc.dbstate,
-                                         self.simpledoc.doc.uistate, 
-                                         'filterbyname', 
-                                         handle)
+                                         self.simpledoc.doc.uistate,
+                                         'filterbyname',
+                                         handle, track=self.track)
         return False # didn't handle event
 
     def on_table_click(self, obj):
@@ -300,7 +311,7 @@ class QuickTable(SimpleTable):
                 handle = handle[0]
             if objclass == 'Person':
                 from gi.repository import GLib
-                # If you emmit the signal here and it causes this table to be deleted, 
+                # If you emmit the signal here and it causes this table to be deleted,
                 # then you'll crash Python:
                 #self.simpledoc.doc.uistate.set_active(handle, 'Person')
                 # So, let's return from this, then change the active person:
@@ -333,6 +344,7 @@ class QuickTable(SimpleTable):
         self.simpledoc = document
         buffer = self.simpledoc.doc.buffer
         text_view = self.simpledoc.doc.text_view
+        text_view.set_sensitive(False)
         model_index = 1 # start after index
         if self._sort_col:
             sort_index = self._columns.index(self._sort_col)
@@ -340,14 +352,10 @@ class QuickTable(SimpleTable):
             sort_index = 0
         treeview = MultiTreeView()
         treeview.enable_model_drag_source(Gdk.ModifierType.BUTTON1_MASK,
-             [],
+                                          [DdTargets.HANDLE_LIST.target()],
                                           Gdk.DragAction.COPY)
-        tglist = Gtk.TargetList.new([])
-        tglist.add(DdTargets.HANDLE_LIST.atom_drag_type, Gtk.TargetFlags.SAME_WIDGET,
-                   0)
-        treeview.drag_source_set_target_list(tglist)
         #treeview.enable_model_drag_dest(DdTargets.all_targets(),
-        #                                Gdk.DragAction.DEFAULT)            
+        #                                Gdk.DragAction.DEFAULT)
         treeview.connect('drag_data_get', self.object_drag_data_get)
         treeview.set_grid_lines(Gtk.TreeViewGridLines.BOTH)
         #treeview.connect('row-activated', on_table_doubleclick, self)
@@ -376,7 +384,7 @@ class QuickTable(SimpleTable):
             column.set_resizable(True)
             if self._sort_vals[cnt] != []:
                 sort_data.append(self._sort_vals[cnt])
-                column.set_sort_column_id(len(self._columns) + 
+                column.set_sort_column_id(len(self._columns) +
                                           len(sort_data))
                 sort_data_types.append(int)
             else:
@@ -384,7 +392,7 @@ class QuickTable(SimpleTable):
             treeview.append_column(column)
             self.model_index_of_column[col] = model_index
             #if model_index == sort_index:
-            # FIXME: what to set here?    
+            # FIXME: what to set here?
             model_index += 1
             cnt += 1
         if self.title:
@@ -417,3 +425,6 @@ class QuickTable(SimpleTable):
         text_view.show_all()
         self.simpledoc.paragraph("")
         self.simpledoc.paragraph("")
+        while Gtk.events_pending():
+            Gtk.main_iteration()
+        text_view.set_sensitive(True)
