@@ -36,7 +36,7 @@ from gi.repository import Gtk
 
 #-------------------------------------------------------------------------
 #
-# GRAMPS modules
+# Gramps modules
 #
 #-------------------------------------------------------------------------
 from gramps.gen.datehandler import format_time, get_date, get_date_valid
@@ -52,15 +52,15 @@ from gramps.gen.const import GRAMPS_LOCALE as glocale
 # Positions in raw data structure
 #
 #-------------------------------------------------------------------------
-COLUMN_HANDLE      = 0
-COLUMN_ID          = 1
-COLUMN_TYPE        = 2
-COLUMN_DATE        = 3
+COLUMN_HANDLE = 0
+COLUMN_ID = 1
+COLUMN_TYPE = 2
+COLUMN_DATE = 3
 COLUMN_DESCRIPTION = 4
-COLUMN_PLACE       = 5
-COLUMN_CHANGE      = 10
-COLUMN_TAGS        = 11
-COLUMN_PRIV        = 12
+COLUMN_PLACE = 5
+COLUMN_CHANGE = 10
+COLUMN_TAGS = 11
+COLUMN_PRIV = 12
 
 INVALID_DATE_FORMAT = config.get('preferences.invalid-date-format')
 
@@ -71,8 +71,8 @@ INVALID_DATE_FORMAT = config.get('preferences.invalid-date-format')
 #-------------------------------------------------------------------------
 class EventModel(FlatBaseModel):
 
-    def __init__(self, db, scol=0, order=Gtk.SortType.ASCENDING, search=None,
-                 skip=set(), sort_map=None):
+    def __init__(self, db, uistate, scol=0, order=Gtk.SortType.ASCENDING,
+                 search=None, skip=set(), sort_map=None):
         self.gen_cursor = db.get_event_cursor
         self.map = db.get_raw_event_data
 
@@ -100,8 +100,8 @@ class EventModel(FlatBaseModel):
             self.column_participant,
             self.column_tag_color
            ]
-        FlatBaseModel.__init__(self, db, scol, order, search=search, skip=skip,
-                               sort_map=sort_map)
+        FlatBaseModel.__init__(self, db, uistate, scol, order, search=search,
+                               skip=skip, sort_map=sort_map)
 
     def destroy(self):
         """
@@ -133,7 +133,7 @@ class EventModel(FlatBaseModel):
             value = get_participant_from_event(self.db, data[COLUMN_HANDLE])
             self.set_cached_value(handle, "PARTICIPANT", value)
         return value
-        
+
     def column_place(self,data):
         if data[COLUMN_PLACE]:
             cached, value = self.get_cached_value(data[0], "PLACE")
@@ -150,13 +150,13 @@ class EventModel(FlatBaseModel):
         return str(EventType(data[COLUMN_TYPE]))
 
     def column_id(self,data):
-        return str(data[COLUMN_ID])
+        return data[COLUMN_ID]
 
     def column_date(self,data):
         if data[COLUMN_DATE]:
             event = Event()
             event.unserialize(data)
-            date_str =  get_date(event)
+            date_str = get_date(event)
             if date_str != "":
                 retval = escape(date_str)
             if not get_date_valid(event):
@@ -174,7 +174,7 @@ class EventModel(FlatBaseModel):
                 return INVALID_DATE_FORMAT % retval
             else:
                 return retval
-            
+
         return ''
 
     def column_private(self, data):
@@ -183,7 +183,7 @@ class EventModel(FlatBaseModel):
         else:
             # There is a problem returning None here.
             return ''
-    
+
     def sort_change(self,data):
         return "%012x" % data[COLUMN_CHANGE]
 
@@ -200,7 +200,7 @@ class EventModel(FlatBaseModel):
             value = self.db.get_tag_from_handle(tag_handle).get_name()
             self.set_cached_value(tag_handle, "TAG_NAME", value)
         return value
-        
+
     def column_tag_color(self, data):
         """
         Return the tag color.
@@ -224,4 +224,5 @@ class EventModel(FlatBaseModel):
         Return the sorted list of tags.
         """
         tag_list = list(map(self.get_tag_name, data[COLUMN_TAGS]))
+        # TODO for Arabic, should the next line's comma be translated?
         return ', '.join(sorted(tag_list, key=glocale.sort_key))
