@@ -15,7 +15,7 @@
 #
 # You should have received a copy of the GNU General Public License
 # along with this program; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #
 
 #-------------------------------------------------------------------------
@@ -23,8 +23,6 @@
 # Python modules
 #
 #-------------------------------------------------------------------------
-from gramps.gen.const import GRAMPS_LOCALE as glocale
-_ = glocale.translation.sgettext
 
 #-------------------------------------------------------------------------
 #
@@ -45,12 +43,26 @@ _LOG = logging.getLogger("gui.widgets.reorderfam")
 # Gramps Modules
 #
 #-------------------------------------------------------------------------
+from gramps.gen.const import GRAMPS_LOCALE as glocale
+_ = glocale.translation.sgettext
 from gramps.gen.db import DbTxn
+from gramps.gen.const import URL_MANUAL_PAGE
 from ..listmodel import ListModel
+from ..display import display_help
 from ..managedwindow import ManagedWindow
 from ..glade import Glade
 from gramps.gen.display.name import displayer as name_displayer
 
+#-------------------------------------------------------------------------
+#
+# Constants
+#
+#-------------------------------------------------------------------------
+
+WIKI_HELP_PAGE = URL_MANUAL_PAGE + "_-_Categories"
+WIKI_HELP_SEC = _('manual|Reorder_Relationships_dialog')
+
+
 #-------------------------------------------------------------------------
 #
 # Reorder class
@@ -61,7 +73,7 @@ class Reorder(ManagedWindow):
     """
     Interface to reorder the families a person is parent in
     """
-    
+
     def __init__(self, state, uistate, track, handle):
         xml = Glade('reorder.glade')
         top = xml.toplevel
@@ -77,22 +89,24 @@ class Reorder(ManagedWindow):
         fenable = len(self.family_list) > 1
 
         self.set_window(top, None, _("Reorder Relationships"))
+        self.setup_configs('interface.reorder', 500, 400)
 
         self.ptree = xml.get_object('ptree')
-        self.pmodel = ListModel(self.ptree, 
-                               [(_('Father'), -1, 200), 
-                                (_('Mother'), -1, 200), 
+        self.pmodel = ListModel(self.ptree,
+                               [(_('Father'), -1, 200),
+                                (_('Mother'), -1, 200),
                                 ('', -1, 0)])
 
         self.ftree = xml.get_object('ftree')
-        self.fmodel = ListModel(self.ftree, 
-                               [(_('Spouse'), -1, 200), 
-                                (_('Relationship'), -1, 200), 
+        self.fmodel = ListModel(self.ftree,
+                               [(_('Spouse'), -1, 200),
+                                (_('Relationship'), -1, 200),
                                 ('', -1, 0)])
 
         xml.get_object('ok').connect('clicked', self.ok_clicked)
         xml.get_object('cancel').connect('clicked', self.cancel_clicked)
-
+        xml.get_object('help').connect(
+            'clicked', lambda x: display_help(WIKI_HELP_PAGE, WIKI_HELP_SEC))
         fup = xml.get_object('fup')
         fup.connect('clicked', self.fup_clicked)
         fup.set_sensitive(fenable)
