@@ -16,8 +16,15 @@
 #
 # You should have received a copy of the GNU General Public License
 # along with this program; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #
+from gramps.gen.plug._pluginreg import *
+from gramps.gen.const import GRAMPS_LOCALE as glocale
+_ = glocale.translation.gettext
+
+MODULE_VERSION="5.1"
+
+# this is the default in gen/plug/_pluginreg.py: plg.require_active = True
 
 #------------------------------------------------------------------------
 #
@@ -26,11 +33,11 @@
 #------------------------------------------------------------------------
 
 plg = newplugin()
-plg.id    = 'ancestor_chart,BKI'
-plg.name  = _("Ancestor Chart")
-plg.description =  _("Produces a graphical ancestral chart")
+plg.id = 'ancestor_chart,BKI'
+plg.name = _("Ancestor Chart")
+plg.description = _("Produces a graphical ancestral chart")
 plg.version = '1.0'
-plg.gramps_target_version = '4.1'
+plg.gramps_target_version = MODULE_VERSION
 plg.status = STABLE
 plg.fname = 'ancestortree.py'
 plg.ptype = REPORT
@@ -42,11 +49,11 @@ plg.optionclass = 'AncestorTreeOptions'
 plg.report_modes = [REPORT_MODE_BKI]
 
 plg = newplugin()
-plg.id    = 'ancestor_chart'
-plg.name  = _("Ancestor Tree")
-plg.description =  _("Produces a graphical ancestral tree")
+plg.id = 'ancestor_chart'
+plg.name = _("Ancestor Tree")
+plg.description = _("Produces a graphical ancestral tree")
 plg.version = '1.0'
-plg.gramps_target_version = '4.1'
+plg.gramps_target_version = MODULE_VERSION
 plg.status = STABLE
 plg.fname = 'ancestortree.py'
 plg.ptype = REPORT
@@ -64,11 +71,11 @@ plg.report_modes = [REPORT_MODE_GUI, REPORT_MODE_CLI]
 #------------------------------------------------------------------------
 
 plg = newplugin()
-plg.id    = 'calendar'
-plg.name  = _("Calendar")
-plg.description =  _("Produces a graphical calendar")
+plg.id = 'calendar'
+plg.name = _("Calendar")
+plg.description = _("Produces a graphical calendar")
 plg.version = '1.0'
-plg.gramps_target_version = '4.1'
+plg.gramps_target_version = MODULE_VERSION
 plg.status = STABLE
 plg.fname = 'calendarreport.py'
 plg.ptype = REPORT
@@ -86,11 +93,11 @@ plg.report_modes = [REPORT_MODE_GUI, REPORT_MODE_BKI, REPORT_MODE_CLI]
 #------------------------------------------------------------------------
 
 plg = newplugin()
-plg.id    = 'descend_chart,BKI'
-plg.name  = _("Descendant Chart")
-plg.description =  _("Produces a graphical descendant chart")
+plg.id = 'descend_chart,BKI'
+plg.name = _("Descendant Chart")
+plg.description = _("Produces a graphical descendant chart")
 plg.version = '1.0'
-plg.gramps_target_version = '4.1'
+plg.gramps_target_version = MODULE_VERSION
 plg.status = STABLE
 plg.fname = 'descendtree.py'
 plg.ptype = REPORT
@@ -102,11 +109,11 @@ plg.optionclass = 'DescendTreeOptions'
 plg.report_modes = [REPORT_MODE_BKI]
 
 plg = newplugin()
-plg.id    = 'descend_chart'
-plg.name  = _("Descendant Tree")
-plg.description =  _("Produces a graphical descendant tree")
+plg.id = 'descend_chart'
+plg.name = _("Descendant Tree")
+plg.description = _("Produces a graphical descendant tree")
 plg.version = '1.0'
-plg.gramps_target_version = '4.1'
+plg.gramps_target_version = MODULE_VERSION
 plg.status = STABLE
 plg.fname = 'descendtree.py'
 plg.ptype = REPORT
@@ -124,15 +131,15 @@ plg.report_modes = [REPORT_MODE_GUI, REPORT_MODE_CLI]
 #------------------------------------------------------------------------
 
 plg = newplugin()
-plg.id    = 'family_descend_chart,BKI'
-plg.name  = _("Family Descendant Chart")
-plg.description =  _("Produces a graphical descendant chart around a family")
+plg.id = 'family_descend_chart,BKI'
+plg.name = _("Family Descendant Chart")
+plg.description = _("Produces a graphical descendant chart around a family")
 plg.version = '1.0'
 plg.status = STABLE
 plg.fname = 'descendtree.py'
 plg.ptype = REPORT
 plg.category = CATEGORY_DRAW
-plg.gramps_target_version = '4.1'
+plg.gramps_target_version = MODULE_VERSION
 plg.authors = ["Craig J. Anderson"]
 plg.authors_email = ["ander882@hotmail.com"]
 plg.require_active = True
@@ -141,15 +148,15 @@ plg.optionclass = 'DescendTreeOptions'
 plg.report_modes = [REPORT_MODE_BKI]
 
 plg = newplugin()
-plg.id    = 'family_descend_chart'
-plg.name  = _("Family Descendant Tree")
-plg.description =  _("Produces a graphical descendant tree around a family")
+plg.id = 'family_descend_chart'
+plg.name = _("Family Descendant Tree")
+plg.description = _("Produces a graphical descendant tree around a family")
 plg.version = '1.0'
 plg.status = STABLE
 plg.fname = 'descendtree.py'
 plg.ptype = REPORT
 plg.category = CATEGORY_DRAW
-plg.gramps_target_version = '4.1'
+plg.gramps_target_version = MODULE_VERSION
 plg.authors = ["Craig J. Anderson"]
 plg.authors_email = ["ander882@hotmail.com"]
 plg.require_active = True
@@ -164,11 +171,11 @@ plg.report_modes = [REPORT_MODE_GUI, REPORT_MODE_CLI]
 #------------------------------------------------------------------------
 
 plg = newplugin()
-plg.id    = 'fan_chart'
-plg.name  = _("Fan Chart")
-plg.description =  _("Produces fan charts")
+plg.id = 'fan_chart'
+plg.name = _("Fan Chart")
+plg.description = _("Produces fan charts")
 plg.version = '1.0'
-plg.gramps_target_version = '4.1'
+plg.gramps_target_version = MODULE_VERSION
 plg.status = STABLE
 plg.fname = 'fanchart.py'
 plg.ptype = REPORT
@@ -186,12 +193,12 @@ plg.report_modes = [REPORT_MODE_GUI, REPORT_MODE_BKI, REPORT_MODE_CLI]
 #------------------------------------------------------------------------
 
 plg = newplugin()
-plg.id    = 'statistics_chart'
-plg.name  = _("Statistics Charts")
-plg.description =  _("Produces statistical bar and pie charts of the people "
+plg.id = 'statistics_chart'
+plg.name = _("Statistics Charts")
+plg.description = _("Produces statistical bar and pie charts of the people "
                     "in the database")
 plg.version = '1.0'
-plg.gramps_target_version = '4.1'
+plg.gramps_target_version = MODULE_VERSION
 plg.status = STABLE
 plg.fname = 'statisticschart.py'
 plg.ptype = REPORT
@@ -210,11 +217,11 @@ plg.require_active = False
 #------------------------------------------------------------------------
 
 plg = newplugin()
-plg.id    = 'timeline'
-plg.name  = _("Timeline Chart")
-plg.description =  _("Produces a timeline chart.")
+plg.id = 'timeline'
+plg.name = _("Timeline Chart")
+plg.description = _("Produces a timeline chart.")
 plg.version = '1.0'
-plg.gramps_target_version = '4.1'
+plg.gramps_target_version = MODULE_VERSION
 plg.status = STABLE
 plg.fname = 'timeline.py'
 plg.ptype = REPORT
