@@ -18,14 +18,25 @@
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #
 
+#-------------------------------------------------------------------------
+#
+# Gtk modules
+#
+#-------------------------------------------------------------------------
+from gi.repository import Gtk
+
+#-------------------------------------------------------------------------
+#
+# Gramps modules
+#
+#-------------------------------------------------------------------------
 from gramps.gui.editors import EditSource, EditCitation
 from gramps.gui.listmodel import ListModel, NOSORT
 from gramps.gen.plug import Gramplet
 from gramps.gui.dbguielement import DbGUIElement
+from gramps.gen.errors import WindowActiveError
 from gramps.gen.const import GRAMPS_LOCALE as glocale
 _ = glocale.translation.gettext
-from gramps.gen.errors import WindowActiveError
-from gi.repository import Gtk
 
 class Citations(Gramplet, DbGUIElement):
 
@@ -46,9 +57,15 @@ class Citations(Gramplet, DbGUIElement):
         """
         called on init of DbGUIElement, connect to db as required.
         """
-        self.callman.register_callbacks({'citation-update': self.changed})
-        self.callman.connect_all(keys=['citation'])
-    
+        self.callman.register_callbacks({'citation-update': self.changed,
+                                         'person-update': self.changed,
+                                         'family-update': self.changed,
+                                         'event-update': self.changed,
+                                         'media-update': self.changed,
+                                         'place-update': self.changed})
+        self.callman.connect_all(keys=['citation', 'family', 'person', 'event',
+                                       'media', 'place'])
+
     def changed(self, handle):
         """
         Called when a registered citation is updated.
@@ -66,14 +83,14 @@ class Citations(Gramplet, DbGUIElement):
                   (_('Source/Citation'), 1, 350),
                   (_('Author'), 2, 200),
                   (_('Publisher'), 3, 150)]
-        self.model = ListModel(top, titles, list_mode="tree", 
+        self.model = ListModel(top, titles, list_mode="tree",
                                event_func=self.invoke_editor)
         return top
-        
+
     def add_citations(self, obj):
         for citation_handle in obj.get_citation_list():
             self.add_citation_ref(citation_handle)
-        
+
     def add_name_citations(self, obj):
         names = [obj.get_primary_name()] + obj.get_alternate_names()
         for name in names:
@@ -87,10 +104,11 @@ class Citations(Gramplet, DbGUIElement):
         for media_ref in obj.get_media_list():
             self.add_citations(media_ref)
             self.add_attribute_citations(media_ref)
-            media = self.dbstate.db.get_object_from_handle(media_ref.ref)
+            media = self.dbstate.db.get_media_from_handle(media_ref.ref)
             self.add_media_citations(media)
 
     def add_media_citations(self, media):
+        self.callman.register_handles({'media': [media.handle]})
         self.add_citations(media)
         self.add_attribute_citations(media)
 
@@ -101,15 +119,18 @@ class Citations(Gramplet, DbGUIElement):
             self.add_event_citations(event)
 
     def add_event_citations(self, event):
+        self.callman.register_handles({'event': [event.handle]})
         self.add_citations(event)
         self.add_attribute_citations(event)
         self.add_mediaref_citations(event)
         place_handle = event.get_place_handle()
-        place = self.dbstate.db.get_place_from_handle(place_handle)
-        if place:
-            self.add_place_citations(place)
+        if place_handle:
+            place = self.dbstate.db.get_place_from_handle(place_handle)
+            if place:
+                self.add_place_citations(place)
 
     def add_place_citations(self, place):
+        self.callman.register_handles({'place': [place.handle]})
         self.add_citations(place)
         self.add_mediaref_citations(place)
 
@@ -121,9 +142,10 @@ class Citations(Gramplet, DbGUIElement):
         for lds in obj.get_lds_ord_list():
             self.add_citations(lds)
             place_handle = lds.get_place_handle()
-            place = self.dbstate.db.get_place_from_handle(place_handle)
-            if place:
-                self.add_place_citations(place)
+            if place_handle:
+                place = self.dbstate.db.get_place_from_handle(place_handle)
+                if place:
+                    self.add_place_citations(place)
 
     def add_association_citations(self, obj):
         for assoc in obj.get_person_ref_list():
@@ -147,13 +169,13 @@ class Citations(Gramplet, DbGUIElement):
         if source_handle not in self.source_nodes:
             node = self.model.add([source_handle, title, author, publisher])
             self.source_nodes[source_handle] = node
-            
-        self.model.add([citation_handle, page, '', ''], 
+
+        self.model.add([citation_handle, page, '', ''],
                        node=self.source_nodes[source_handle])
 
     def check_citations(self, obj):
         return True if obj.get_citation_list() else False
-        
+
     def check_name_citations(self, obj):
         names = [obj.get_primary_name()] + obj.get_alternate_names()
         for name in names:
@@ -173,7 +195,7 @@ class Citations(Gramplet, DbGUIElement):
                 return True
             if self.check_attribute_citations(media_ref):
                 return True
-            media = self.dbstate.db.get_object_from_handle(media_ref.ref)
+            media = self.dbstate.db.get_media_from_handle(media_ref.ref)
             if self.check_media_citations(media):
                 return True
         return False
@@ -186,12 +208,13 @@ class Citations(Gramplet, DbGUIElement):
         return False
 
     def check_eventref_citations(self, obj):
-        for event_ref in obj.get_event_ref_list():
-            if self.check_attribute_citations(event_ref):
-                return True
-            event = self.dbstate.db.get_event_from_handle(event_ref.ref)
-            if self.check_event_citations(event):
-                return True
+        if obj:
+            for event_ref in obj.get_event_ref_list():
+                if self.check_attribute_citations(event_ref):
+                    return True
+                event = self.dbstate.db.get_event_from_handle(event_ref.ref)
+                if self.check_event_citations(event):
+                    return True
         return False
 
     def check_event_citations(self, event):
@@ -202,9 +225,10 @@ class Citations(Gramplet, DbGUIElement):
         if self.check_mediaref_citations(event):
             return True
         place_handle = event.get_place_handle()
-        place = self.dbstate.db.get_place_from_handle(place_handle)
-        if place and self.check_place_citations(place):
-            return True
+        if place_handle:
+            place = self.dbstate.db.get_place_from_handle(place_handle)
+            if place and self.check_place_citations(place):
+                return True
         return False
 
     def check_place_citations(self, place):
@@ -225,9 +249,10 @@ class Citations(Gramplet, DbGUIElement):
             if self.check_citations(lds):
                 return True
             place_handle = lds.get_place_handle()
-            place = self.dbstate.db.get_place_from_handle(place_handle)
-            if place and self.check_place_citations(place):
-                return True
+            if place_handle:
+                place = self.dbstate.db.get_place_from_handle(place_handle)
+                if place and self.check_place_citations(place):
+                    return True
         return False
 
     def check_association_citations(self, obj):
@@ -243,7 +268,7 @@ class Citations(Gramplet, DbGUIElement):
         model, iter_ = treeview.get_selection().get_selected()
         if iter_:
             handle = model.get_value(iter_, 0)
-            # bug 9094. 
+            # bug 9094.
             # str(model.get_path(iter_)) return something like NNN:MMM
             # So if we have only NNN, it's a node
             # removing the str() solves the problem.
@@ -296,7 +321,6 @@ class PersonCitations(Citations):
         if active_handle:
             active = self.dbstate.db.get_person_from_handle(active_handle)
             if active:
-                self.callman.register_obj(active)
                 self.display_citations(active)
             else:
                 self.set_has_data(False)
@@ -308,6 +332,7 @@ class PersonCitations(Citations):
         Display the citations for the active person.
         """
         self.source_nodes = {}
+        self.callman.register_handles({'person': [person.handle]})
         self.add_citations(person)
         self.add_eventref_citations(person)
         for handle in person.get_family_handle_list():
@@ -373,7 +398,6 @@ class EventCitations(Citations):
         if active_handle:
             active = self.dbstate.db.get_event_from_handle(active_handle)
             if active:
-                self.callman.register_obj(active)
                 self.display_citations(active)
             else:
                 self.set_has_data(False)
@@ -421,7 +445,6 @@ class FamilyCitations(Citations):
         if active_handle:
             active = self.dbstate.db.get_family_from_handle(active_handle)
             if active:
-                self.callman.register_obj(active)
                 self.display_citations(active)
             else:
                 self.set_has_data(False)
@@ -433,6 +456,7 @@ class FamilyCitations(Citations):
         Display the citations for the active family.
         """
         self.source_nodes = {}
+        self.callman.register_handles({'family': [family.handle]})
         self.add_citations(family)
         self.add_eventref_citations(family)
         self.add_attribute_citations(family)
@@ -482,7 +506,6 @@ class PlaceCitations(Citations):
         if active_handle:
             active = self.dbstate.db.get_place_from_handle(active_handle)
             if active:
-                self.callman.register_obj(active)
                 self.display_citations(active)
             else:
                 self.set_has_data(False)
@@ -518,7 +541,7 @@ class MediaCitations(Citations):
     def update_has_data(self):
         active_handle = self.get_active('Media')
         if active_handle:
-            active = self.dbstate.db.get_object_from_handle(active_handle)
+            active = self.dbstate.db.get_media_from_handle(active_handle)
             self.set_has_data(self.get_has_data(active))
         else:
             self.set_has_data(False)
@@ -528,9 +551,8 @@ class MediaCitations(Citations):
         self.callman.unregister_all()
         active_handle = self.get_active('Media')
         if active_handle:
-            active = self.dbstate.db.get_object_from_handle(active_handle)
+            active = self.dbstate.db.get_media_from_handle(active_handle)
             if active:
-                self.callman.register_obj(active)
                 self.display_citations(active)
             else:
                 self.set_has_data(False)
