@@ -20,20 +20,6 @@
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #
 
-#------------------------------------------------------------------------
-#
-# Html
-#
-#------------------------------------------------------------------------
-
-from __future__ import print_function
-
-#------------------------------------------------------------------------
-# Python modules
-#------------------------------------------------------------------------
-import re
-
-from gramps.gen.constfunc import STRTYPE, cuni
 """
 HTML operations.
 
@@ -41,19 +27,24 @@ This module exports the Html class
 
 """
 
-__all__ = ['Html']
+#------------------------------------------------------------------------
+# Python modules
+#------------------------------------------------------------------------
+import re
 
 #------------------------------------------------------------------------
 #
-# GRAMPS modules
+# Gramps modules
 #
 #------------------------------------------------------------------------
 from gramps.gen.const import GRAMPS_LOCALE as glocale
+
 #------------------------------------------------------------------------
 #
 # Constants
 #
 #------------------------------------------------------------------------
+__all__ = ['Html']
 
 #------------------------------------------------------------------------
 #
@@ -79,7 +70,7 @@ _HTML5 = ""
 
 #------------------------------------------------------------------------
 #
-# XML Namespace constant for use in <html xmlns=...> tags 
+# XML Namespace constant for use in <html xmlns=...> tags
 #
 #------------------------------------------------------------------------
 
@@ -94,15 +85,15 @@ _XMLNS = "http://www.w3.org/1999/xhtml"
 # Set of html tags that do not use a complementary closing tag, but close with
 # /> instead
 _START_CLOSE = set([
-    'area', 
-    'base', 
-    'br', 
-    'frame', 
+    'area',
+    'base',
+    'br',
+    'frame',
     'hr',
-    'img', 
-    'input', 
-    'link', 
-    'meta', 
+    'img',
+    'input',
+    'link',
+    'meta',
     'param'
     ])
 
@@ -116,7 +107,7 @@ class Html(list):
     """
     HTML class: Manages a rooted tree of HTML objects
     """
-    __slots__ = ['items', 'indent', 'inline', 'close']
+    __slots__ = ['items', 'indent', 'inline', 'close', 'cms']
 #
     @staticmethod
     def xmldecl(version=1.0, encoding="UTF-8", standalone="no"):
@@ -146,16 +137,16 @@ class Html(list):
         :type  public: string
         :param public: class of this DOCTYPE. Defaults to 'PUBLIC
         :type  external_id: string
-        :param external_id: external identifier of this DOCTYPE. 
+        :param external_id: external identifier of this DOCTYPE.
                             Defaults to XHTML 1.0 STRICT
         :type  args: object
-        :param args: 0 or more positional parameters to be added to this    
+        :param args: 0 or more positional parameters to be added to this
                      DOCTYPE.
         """
         return (
             '<!DOCTYPE %s %s %s' % (
                 name,
-                public, 
+                public,
                 external_id,
                 )
             ).rstrip() + '>'
@@ -171,7 +162,7 @@ class Html(list):
         :param lang: language to be used. Defaul = 'en'
         :rtype:   reference to new Html instance
         :returns:  reference to the newly-created Html instances for <html> object
-        """      
+        """
         return Html('html',
             indent=False,
             xmlns=xmlns,
@@ -183,9 +174,9 @@ class Html(list):
     def head(title=None, encoding='utf-8', html5=True, *args, **keywargs):
         """
         Build and return a properly-formated <head> object
-    
+
         :type  title: string or None
-        :param title: title for HTML page. Default=None. If None no 
+        :param title: title for HTML page. Default=None. If None no
                     title tag is written
         :type  encoding: string
         :param encoding: encoding to be used. Default = 'utf-8'
@@ -193,10 +184,10 @@ class Html(list):
                       if pre-html5 syntax required
         :rtype:  reference to new Html instance
         :returns: reference to the newly-created Html instances for <head> object
-        """ 
+        """
 
-        head = Html('head', *args, **keywargs) 
-        if title is not None: 
+        head = Html('head', *args, **keywargs)
+        if title is not None:
             head += (Html('title', title, inline=True, indent=True))
         if html5:
             head += Html('meta', charset=encoding, indent=True)
@@ -208,10 +199,10 @@ class Html(list):
         return head
 #
     @staticmethod
-    def page(title=None, encoding='utf-8', lang='en', html5=True, *args, **keywargs):
+    def page(title=None, encoding='utf-8', lang='en', html5=True, cms=False, *args, **keywargs):
         """
         This function prepares a new Html class based page and returns
-    
+
         :type  title: string
         :param title: title for HTML page. Default=None
         :type  encoding: string
@@ -236,17 +227,20 @@ class Html(list):
                lang=lang,
                html5=html5,
                indent=False,
-               *args, **keywargs 
+               *args, **keywargs
                )
 #
-        body = Html('body', indent=False, *args, **keywargs)
+        if cms:
+            body = Html('div', class_ = "body", indent=False, *args, **keywargs)
+        else:
+            body = Html('body', indent=False, *args, **keywargs)
         page += (head, body)
         return page, head, body
 #
     def __init__(self, tag='html', *args, **keywargs):
         """
         Class Constructor: Returns a new instance of the Html class
-        
+
         :type  tag: string
         :param tag: The HTML tag. Default is 'html'
         :type  args: optional positional parameters
@@ -275,7 +269,7 @@ class Html(list):
                          attributes
         :rtype:   object reference
         :returns:  reference to the newly-created Html instance
-        
+
         For full usage of the Html class with examples, please see the wiki
         page at: http://www.gramps-project.org/wiki/index.php?title=Libhtml
         """
@@ -286,11 +280,11 @@ class Html(list):
         self.indent, self.close, self.inline = True, True, False
 #
 #       Handle keyword arguments passed to this constructor.
-#       Keywords that we process directly are handled. 
-#       Keywords we don't recognize are saved for later 
+#       Keywords that we process directly are handled.
+#       Keywords we don't recognize are saved for later
 #       addition to the opening tag as attributes.
 #
-        for keyw, arg in keywargs.items():
+        for keyw, arg in sorted(keywargs.items()):
             if (keyw in ['indent', 'close', 'inline'] and
                arg in [True, False, None]):
                 setattr(self, keyw, arg)
@@ -304,7 +298,7 @@ class Html(list):
         if tag[0] == '<':               # if caller provided preformatted tag?
             self[0:] = [tag]            #   add it in
             self.close = None           #   caller must close the tag
-        else: 
+        else:
             if tag in _START_CLOSE:     # if tag in special list
                 self.close = False      #   it needs no closing tag
             begin = '<%s%s%s>' % (      # build opening tag with attributes
@@ -330,7 +324,7 @@ class Html(list):
         :returns: reference to object with new value added
         """
         if (isinstance(value, Html) or not hasattr(value, '__iter__') or
-                isinstance(value, STRTYPE)):
+                isinstance(value, str)):
             value = [value]
         index = len(self) - (1 if self.close else 0)
         self[index:index] = value
@@ -411,17 +405,17 @@ class Html(list):
         """
         if self.indent is None:
             tabs = ''
-        elif self.indent: 
+        elif self.indent:
             tabs += indent
         if self.inline:                         # if inline, write all list and
-            method(cuni('%s%s' % (tabs, self)))       # nested list elements
+            method(str('%s%s' % (tabs, self)))       # nested list elements
 #
         else:
             for item in self[:]:                # else write one at a time
                 if isinstance(item, Html):      # recurse if nested Html class
                     item.write(method=method, indent=indent, tabs=tabs)
                 else:
-                    method(cuni('%s%s' % (tabs, item)))  # else write the line
+                    method(str('%s%s' % (tabs, item)))  # else write the line
 #
     def addXML(self, version=1.0, encoding="UTF-8", standalone="no"):
         """
@@ -449,10 +443,10 @@ class Html(list):
         :type  name: string
         :param name: name of this DOCTYPE. Defaults to "html"
         :type  external_id: string
-        :param external_id: external identifier of this DOCTYPE. 
+        :param external_id: external identifier of this DOCTYPE.
                             Defaults to XHTML 1.0 STRICT
         :type  args: object
-        :param args: 0 or more positional parameters to be added to this    
+        :param args: 0 or more positional parameters to be added to this
                      DOCTYPE.
         """
         doctype = (
@@ -487,9 +481,9 @@ class Html(list):
         :param name: new HTML tag
         """
         curtag = self.tag
-        
+
         # Replace closing tag, if any
-        
+
         if self[-1] == '</%s>' % curtag:
             self[-1] = '</%s>' % newtag
 
@@ -518,9 +512,9 @@ class Html(list):
         beg = len(self.tag) + 1
 
         # See if self-closed or normal
-        
+
         end = -2 if self.close is False else -1
-        self[0] = self[0][:beg] + ' ' + value + self[0][end:]        
+        self[0] = self[0][:beg] + ' ' + value + self[0][end:]
 #
     def __delattr(self):
         """
@@ -529,7 +523,7 @@ class Html(list):
         self[0] = '<' + self.tag + (
 
                 # Set correct closing delimiter(s)
-        
+
                 ' />' if self.close is False else '>'
                 )
 #
@@ -540,7 +534,7 @@ class Html(list):
         Returns list of items between opening and closing tags
 
         :rtype:  list
-        :returns: list of items between opening and closing HTML tags 
+        :returns: list of items between opening and closing HTML tags
         """
         return self[1:-1]
 #
@@ -554,7 +548,7 @@ class Html(list):
         if len(self) < 2:
             raise AttributeError('No closing tag. Cannot set inside value')
         if (isinstance(value, Html) or not hasattr(value, '__iter__') or
-                isinstance(value, STRTYPE)):
+                isinstance(value, str)):
             value = [value]
         self[1:-1] = value
 #
@@ -590,5 +584,6 @@ def htmltest():
     pass
 
 if __name__ == '__main__':
-    from libhtmltest import htmltest
-    htmltest()    
+    #from libhtmltest import htmltest
+    #htmltest()
+    pass
