@@ -2,9 +2,9 @@
 # Gramps - a GTK+/GNOME based genealogy program
 #
 # Copyright (C) 2000-2007  Donald N. Allingham
-# Copyright (C) 2007-2009  Brian G. Matherly
+# Copyright (C) 2007-2012  Brian G. Matherly
 # Copyright (C) 2010       Jakim Friant
-# Copyright (C) 2012-2013  Paul Franklin
+# Copyright (C) 2012-2014  Paul Franklin
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -41,13 +41,15 @@ from gramps.gen.errors import ReportError
 from gramps.gen.lib import ChildRefType
 from gramps.gen.plug.menu import (BooleanOption, NumberOption, PersonOption)
 from gramps.gen.plug.docgen import (IndexMark, FontStyle, ParagraphStyle,
-                                    FONT_SANS_SERIF, INDEX_TYPE_TOC, 
+                                    FONT_SANS_SERIF, INDEX_TYPE_TOC,
                                     PARA_ALIGN_CENTER)
 from gramps.gen.plug.report import Report
-from gramps.gen.plug.report import utils as ReportUtils
+from gramps.gen.plug.report import utils
 from gramps.gen.plug.report import MenuReportOptions
 from gramps.gen.plug.report import stdoptions
 from gramps.plugins.lib.libnarrate import Narrator
+from gramps.gen.proxy import CacheProxyDb
+from gramps.gen.display.name import displayer as _nd
 
 #------------------------------------------------------------------------
 #
@@ -72,43 +74,52 @@ class AncestorReport(Report):
     def __init__(self, database, options, user):
         """
         Create the AncestorReport object that produces the Ahnentafel report.
-        
+
         The arguments are:
 
-        database        - the GRAMPS database instance
+        database        - the Gramps database instance
         options         - instance of the Options class for this report
         user            - a gen.user.User() instance
 
         This report needs the following parameters (class variables)
         that come in the options class.
-        
+
         gen       - Maximum number of generations to include.
         pagebbg   - Whether to include page breaks between generations.
         name_format   - Preferred format to display names
-
+        incl_private  - Whether to include private data
+        namebrk       - Whether a line break should follow the name
+        inc_id        - Whether to include Gramps IDs
+        living_people - How to handle living people
+        years_past_death - Consider as living this many years after death
         """
         Report.__init__(self, database, options, user)
 
         self.map = {}
-        
         menu = options.menu
+
+        self.set_locale(menu.get_option_by_name('trans').get_value())
+
+        stdoptions.run_date_format_option(self, menu)
+
+        stdoptions.run_private_data_option(self, menu)
+        stdoptions.run_living_people_option(self, menu, self._locale)
+        self.database = CacheProxyDb(self.database)
+
         self.max_generations = menu.get_option_by_name('maxgen').get_value()
         self.pgbrk = menu.get_option_by_name('pagebbg').get_value()
         self.opt_namebrk = menu.get_option_by_name('namebrk').get_value()
+        self.want_ids = menu.get_option_by_name('inc_id').get_value()
+
         pid = menu.get_option_by_name('pid').get_value()
-        self.center_person = database.get_person_from_gramps_id(pid)
-        if (self.center_person == None) :
-            raise ReportError(_("Person %s is not in the Database") % pid )
+        self.center_person = self.database.get_person_from_gramps_id(pid)
+        if self.center_person is None:
+            raise ReportError(_("Person %s is not in the Database") % pid)
 
-        lang = menu.get_option_by_name('trans').get_value()
-        rlocale = self.set_locale(lang)
-
-        name_format = menu.get_option_by_name("name_format").get_value()
-        if name_format != 0:
-            self._name_display.set_default_format(name_format)
+        stdoptions.run_name_format_option(self, menu)
 
         self.__narrator = Narrator(self.database,  use_fulldate=True,
-                                   nlocale=rlocale)
+                                   nlocale=self._locale)
 
     def apply_filter(self, person_handle, index, generation=1):
         """
@@ -122,7 +133,7 @@ class AncestorReport(Report):
         if not person_handle or generation > self.max_generations:
             return
 
-        # store the person in the map based off their index number 
+        # store the person in the map based off their index number
         # which is passed to the routine.
         self.map[index] = person_handle
 
@@ -132,6 +143,8 @@ class AncestorReport(Report):
         # we have to handle that parents may not
 
         person = self.database.get_person_from_handle(person_handle)
+        if person is None:
+            return
 
         father_handle = None
         mother_handle = None
@@ -147,8 +160,8 @@ class AncestorReport(Report):
             if ref:
 
                 # If the father_handle is not defined and the relationship is
-                # BIRTH, then we have found the birth father. Same applies to 
-                # the birth mother. If for some reason, the we have multiple 
+                # BIRTH, then we have found the birth father. Same applies to
+                # the birth mother. If for some reason, the we have multiple
                 # people defined as the birth parents, we will select based on
                 # priority in the list
 
@@ -159,7 +172,7 @@ class AncestorReport(Report):
                    ref[0].get_mother_relation() == ChildRefType.BIRTH:
                     mother_handle = family.get_mother_handle()
 
-        # Recursively call the function. It is okay if the handle is None,  
+        # Recursively call the function. It is okay if the handle is None,
         # since routine handles a handle of None
 
         self.apply_filter(father_handle, index*2, generation+1)
@@ -171,22 +184,22 @@ class AncestorReport(Report):
         is opened and ready for writing.
         """
 
-        # Call apply_filter to build the self.map array of people in the 
+        # Call apply_filter to build the self.map array of people in the
         # database that match the ancestry.
 
         self.apply_filter(self.center_person.get_handle(), 1)
 
-        # Write the title line. Set in INDEX marker so that this section will be
+        # Write the title line. Set an INDEX mark so that this section will be
         # identified as a major category if this is included in a Book report.
 
         name = self._name_display.display_formal(self.center_person)
         # feature request 2356: avoid genitive form
         title = self._("Ahnentafel Report for %s") % name
-        mark = IndexMark(title, INDEX_TYPE_TOC, 1)        
+        mark = IndexMark(title, INDEX_TYPE_TOC, 1)
         self.doc.start_paragraph("AHN-Title")
         self.doc.write_text(title, mark)
         self.doc.end_paragraph()
-    
+
         # get the entries out of the map, and sort them.
 
         generation = 0
@@ -214,22 +227,26 @@ class AncestorReport(Report):
 
             self.doc.start_paragraph("AHN-Entry","%d." % key)
             person = self.database.get_person_from_handle(self.map[key])
+            if person is None:
+                continue
             name = self._name_display.display(person)
-            mark = ReportUtils.get_person_mark(self.database, person)
-        
+            mark = utils.get_person_mark(self.database, person)
+
             # write the name in bold
             self.doc.start_bold()
             self.doc.write_text(name.strip(), mark)
             self.doc.end_bold()
+            if self.want_ids:
+                self.doc.write_text(' (%s)' % person.get_gramps_id())
 
-            # terminate with a period if it is not already terminated. 
+            # terminate with a period if it is not already terminated.
             # This can happen if the person's name ends with something 'Jr.'
-            if name[-1:] == '.':
+            if name[-1:] == '.' and not self.want_ids:
                 self.doc.write_text(" ")
             else:
                 self.doc.write_text(". ")
 
-            # Add a line break if requested (not implemented yet)
+            # Add a line break if requested
             if self.opt_namebrk:
                 self.doc.write_text('\n')
 
@@ -239,7 +256,7 @@ class AncestorReport(Report):
             self.doc.write_text(self.__narrator.get_christened_string())
             self.doc.write_text(self.__narrator.get_died_string())
             self.doc.write_text(self.__narrator.get_buried_string())
-                        
+
             self.doc.end_paragraph()
 
 #------------------------------------------------------------------------
@@ -254,34 +271,53 @@ class AncestorOptions(MenuReportOptions):
     """
 
     def __init__(self, name, dbase):
+        self.__db = dbase
+        self.__pid = None
         MenuReportOptions.__init__(self, name, dbase)
-        
+
+    def get_subject(self):
+        """ Return a string that describes the subject of the report. """
+        gid = self.__pid.get_value()
+        person = self.__db.get_person_from_gramps_id(gid)
+        return _nd.display(person)
+
     def add_menu_options(self, menu):
         """
         Add options to the menu for the ancestor report.
         """
         category_name = _("Report Options")
-        
-        pid = PersonOption(_("Center Person"))
-        pid.set_help(_("The center person for the report"))
-        menu.add_option(category_name, "pid", pid)
 
-        stdoptions.add_name_format_option(menu, category_name)
-        
+        self.__pid = PersonOption(_("Center Person"))
+        self.__pid.set_help(_("The center person for the report"))
+        menu.add_option(category_name, "pid", self.__pid)
+
         maxgen = NumberOption(_("Generations"), 10, 1, 100)
-        maxgen.set_help(_("The number of generations to include in the report"))
+        maxgen.set_help(
+            _("The number of generations to include in the report"))
         menu.add_option(category_name, "maxgen", maxgen)
-        
+
+        stdoptions.add_gramps_id_option(menu, category_name)
+
         pagebbg = BooleanOption(_("Page break between generations"), False)
         pagebbg.set_help(
                      _("Whether to start a new page after each generation."))
         menu.add_option(category_name, "pagebbg", pagebbg)
-        
+
         namebrk = BooleanOption(_("Add linebreak after each name"), False)
-        namebrk.set_help(_("Indicates if a line break should follow the name."))
+        namebrk.set_help(_("Whether a line break should follow the name."))
         menu.add_option(category_name, "namebrk", namebrk)
 
-        stdoptions.add_localization_option(menu, category_name)
+        category_name = _("Report Options (2)")
+
+        stdoptions.add_name_format_option(menu, category_name)
+
+        stdoptions.add_private_data_option(menu, category_name)
+
+        stdoptions.add_living_people_option(menu, category_name)
+
+        locale_opt = stdoptions.add_localization_option(menu, category_name)
+
+        stdoptions.add_date_format_option(menu, category_name, locale_opt)
 
     def make_default_style(self, default_style):
         """
@@ -305,7 +341,7 @@ class AncestorOptions(MenuReportOptions):
                         14pt
             Paragraph : Second level header
                         0.125cm top and bottom margins
-                        
+
         AHN - Normal text display for each entry
 
             Font      : default
@@ -323,10 +359,10 @@ class AncestorOptions(MenuReportOptions):
         para.set_header_level(1)
         para.set_top_margin(0.25)
         para.set_bottom_margin(0.25)
-        para.set_alignment(PARA_ALIGN_CENTER)       
-        para.set_description(_('The style used for the title of the page.'))
+        para.set_alignment(PARA_ALIGN_CENTER)
+        para.set_description(_('The style used for the title.'))
         default_style.add_paragraph_style("AHN-Title", para)
-    
+
         #
         # AHN-Generation
         #
@@ -336,16 +372,16 @@ class AncestorOptions(MenuReportOptions):
         para.set_font(font)
         para.set_header_level(2)
         para.set_top_margin(0.125)
-        para.set_bottom_margin(0.125)        
+        para.set_bottom_margin(0.125)
         para.set_description(_('The style used for the generation header.'))
         default_style.add_paragraph_style("AHN-Generation", para)
-    
+
         #
         # AHN-Entry
         #
         para = ParagraphStyle()
         para.set(first_indent=-1.0, lmargin=1.0)
         para.set_top_margin(0.125)
-        para.set_bottom_margin(0.125)        
+        para.set_bottom_margin(0.125)
         para.set_description(_('The basic style used for the text display.'))
         default_style.add_paragraph_style("AHN-Entry", para)
