@@ -39,7 +39,7 @@ from gi.repository import Gtk
 
 #------------------------------------------------------------------------
 #
-# GRAMPS modules
+# Gramps modules
 #
 #------------------------------------------------------------------------
 from gramps.gen.filters import GenericFilter, rules
@@ -52,14 +52,14 @@ from gramps.gen.errors import WindowActiveError
 from gramps.gen.datehandler import get_date
 from gramps.gui.dialog import WarningDialog
 from gramps.gui.plug import tool
-from gramps.gen.plug.report import utils as ReportUtils
+from gramps.gen.plug.report import utils
 from gramps.gui.display import display_help
 from gramps.gui.managedwindow import ManagedWindow
 from gramps.gen.const import GRAMPS_LOCALE as glocale
 _ = glocale.translation.sgettext
 from gramps.gui.glade import Glade
 from gramps.gui.editors import FilterEditor
-from gramps.gen.constfunc import conv_to_unicode, get_curr_dir
+from gramps.gen.constfunc import get_curr_dir
 
 #-------------------------------------------------------------------------
 #
@@ -67,14 +67,14 @@ from gramps.gen.constfunc import conv_to_unicode, get_curr_dir
 #
 #-------------------------------------------------------------------------
 WIKI_HELP_PAGE = '%s_-_Tools' % URL_MANUAL_PAGE
-WIKI_HELP_SEC = _('manual|Compare_Individual_Events...')
+WIKI_HELP_SEC = _('manual|Compare_Individual_Events')
 
 #------------------------------------------------------------------------
 #
 # EventCmp
 #
 #------------------------------------------------------------------------
-class TableReport(object):
+class TableReport:
     """
     This class provides an interface for the spreadsheet table
     used to save the data into the file.
@@ -124,7 +124,7 @@ class EventComparison(tool.Tool,ManagedWindow):
         ManagedWindow.__init__(self, uistate, [], self)
         self.qual = 0
 
-        self.filterDialog = Glade(toplevel="filters")
+        self.filterDialog = Glade(toplevel="filters", also_load=["liststore1"])
         self.filterDialog.connect_signals({
             "on_apply_clicked"       : self.on_apply_clicked,
             "on_editor_clicked"      : self.filter_editor_clicked,
@@ -138,6 +138,7 @@ class EventComparison(tool.Tool,ManagedWindow):
         self.label = _('Event comparison filter selection')
         self.set_window(window,self.filterDialog.get_object('title'),
                         self.label)
+        self.setup_configs('interface.eventcomparison', 640, 220)
 
         self.on_filters_changed('Person')
         uistate.connect('filters-changed', self.on_filters_changed)
@@ -160,7 +161,7 @@ class EventComparison(tool.Tool,ManagedWindow):
             self.filters.set_active(0)
 
     def on_help_clicked(self, obj):
-        """Display the relevant portion of GRAMPS manual"""
+        """Display the relevant portion of Gramps manual"""
         display_help(webpage=WIKI_HELP_PAGE, section=WIKI_HELP_SEC)
 
     def build_menu_names(self, obj):
@@ -176,9 +177,8 @@ class EventComparison(tool.Tool,ManagedWindow):
     def on_apply_clicked(self, obj):
         cfilter = self.filter_model[self.filters.get_active()][1]
 
-        progress_bar = ProgressMeter(_('Comparing events'),
-                                        '',
-                                        parent=self.window)
+        progress_bar = ProgressMeter(_('Comparing events'), '',
+                                     parent=self.window)
         progress_bar.set_pass(_('Selecting people'),1)
 
         plist = cfilter.apply(self.db,
@@ -191,9 +191,10 @@ class EventComparison(tool.Tool,ManagedWindow):
         self.options.handler.save_options()
 
         if len(plist) == 0:
-            WarningDialog(_("No matches were found"), parent=self.window)
+            WarningDialog(_("No matches were found"),
+                          parent=self.window)
         else:
-            DisplayChart(self.dbstate,self.uistate,plist,self.track)
+            EventComparisonResults(self.dbstate, self.uistate, plist, self.track)
 
 #-------------------------------------------------------------------------
 #
@@ -217,7 +218,7 @@ def fix(line):
 #
 #
 #-------------------------------------------------------------------------
-class DisplayChart(ManagedWindow):
+class EventComparisonResults(ManagedWindow):
     def __init__(self,dbstate,uistate,people_list,track):
         self.dbstate = dbstate
         self.uistate = uistate
@@ -229,7 +230,7 @@ class DisplayChart(ManagedWindow):
         self.row_data = []
         self.save_form = None
 
-        self.topDialog = Glade()
+        self.topDialog = Glade(toplevel="eventcmp")
         self.topDialog.connect_signals({
             "on_write_table"        : self.on_write_table,
             "destroy_passed_object" : self.close,
@@ -241,6 +242,7 @@ class DisplayChart(ManagedWindow):
         window = self.topDialog.toplevel
         self.set_window(window, self.topDialog.get_object('title'),
                         _('Event Comparison Results'))
+        self.setup_configs('interface.eventcomparisonresults', 750, 400)
 
         self.eventlist = self.topDialog.get_object('treeview')
         self.sort = Sort(self.db)
@@ -269,7 +271,7 @@ class DisplayChart(ManagedWindow):
         pass
 
     def on_help_clicked(self, obj):
-        """Display the relevant portion of GRAMPS manual"""
+        """Display the relevant portion of Gramps manual"""
         display_help(webpage=WIKI_HELP_PAGE, section=WIKI_HELP_SEC)
 
     def build_menu_names(self, obj):
@@ -306,8 +308,8 @@ class DisplayChart(ManagedWindow):
         self.progress_bar.close()
 
     def build_row_data(self):
-        self.progress_bar = ProgressMeter(_('Comparing Events'),'',
-                                            parent=self.window)
+        self.progress_bar = ProgressMeter(
+            _('Comparing Events'), '', parent=self.uistate.window)
         self.progress_bar.set_pass(_('Building data'),len(self.my_list))
         for individual_id in self.my_list:
             individual = self.db.get_person_from_handle(individual_id)
@@ -403,7 +405,7 @@ class DisplayChart(ManagedWindow):
         f.hide()
 
         if status == Gtk.ResponseType.OK:
-            name = conv_to_unicode(f.get_filename())
+            name = f.get_filename()
             doc = ODSTab(len(self.row_data))
             doc.creator(self.db.get_researcher().get_name())
 
@@ -448,7 +450,7 @@ class EventComparisonOptions(tool.ToolOptions):
         self.options_dict = {
             'filter'   : 0,
         }
-        filters = ReportUtils.get_person_filters(None)
+        filters = utils.get_person_filters(None)
         self.options_help = {
             'filter'   : ("=num","Filter number.",
                           [ filt.get_name() for filt in filters ],
