@@ -3,7 +3,7 @@
 #
 # Gramps - a GTK+/GNOME based genealogy program
 #
-# Copyright (C) 2011  Serge Noiraud
+# Copyright (C) 2011-2016  Serge Noiraud
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -33,10 +33,6 @@ _ = glocale.translation.gettext
 import operator
 from gi.repository import Gtk
 from gi.repository import Gdk
-from gi.repository import GObject
-import time
-import threading
-from math import *
 from gi.repository import GLib
 
 #-------------------------------------------------------------------------
@@ -58,11 +54,9 @@ from gramps.gen.datehandler import displayer
 from gramps.gen.display.name import displayer as _nd
 from gramps.gen.display.place import displayer as _pd
 from gramps.gen.utils.place import conv_lat_lon
-from gramps.gui.views.navigationview import NavigationView
 from gramps.gui.views.bookmarks import PersonBookmarks
 from gramps.plugins.lib.maps import constants
 from gramps.plugins.lib.maps.geography import GeoGraphyView
-from gramps.gui.selectors import SelectorFactory
 
 #-------------------------------------------------------------------------
 #
@@ -70,42 +64,112 @@ from gramps.gui.selectors import SelectorFactory
 #
 #-------------------------------------------------------------------------
 
-_UI_DEF = '''\
-<ui>
-<menubar name="MenuBar">
-<menu action="GoMenu">
-  <placeholder name="CommonGo">
-    <menuitem action="Back"/>
-    <menuitem action="Forward"/>
-    <separator/>
-    <menuitem action="HomePerson"/>
-    <separator/>
-  </placeholder>
-</menu>
-<menu action="EditMenu">
-  <placeholder name="CommonEdit">
-    <menuitem action="PrintView"/>
-  </placeholder>
-</menu>
-<menu action="BookMenu">
-  <placeholder name="AddEditBook">
-    <menuitem action="AddBook"/>
-    <menuitem action="EditBook"/>
-  </placeholder>
-</menu>
-</menubar>
-<toolbar name="ToolBar">
-<placeholder name="CommonNavigation">
-  <toolitem action="Back"/>  
-  <toolitem action="Forward"/>  
-  <toolitem action="HomePerson"/>
-</placeholder>
-<placeholder name="CommonEdit">
-  <toolitem action="PrintView"/>
-</placeholder>
-</toolbar>
-</ui>
-'''
+_UI_DEF = [
+    '''
+      <placeholder id="CommonGo">
+      <section>
+        <item>
+          <attribute name="action">win.Back</attribute>
+          <attribute name="label" translatable="yes">_Back</attribute>
+        </item>
+        <item>
+          <attribute name="action">win.Forward</attribute>
+          <attribute name="label" translatable="yes">_Forward</attribute>
+        </item>
+      </section>
+      <section>
+        <item>
+          <attribute name="action">win.HomePerson</attribute>
+          <attribute name="label" translatable="yes">_Home</attribute>
+        </item>
+      </section>
+      </placeholder>
+''',
+    '''
+      <section id='CommonEdit' groups='RW'>
+        <item>
+          <attribute name="action">win.PrintView</attribute>
+          <attribute name="label" translatable="yes">Print...</attribute>
+        </item>
+      </section>
+''',
+    '''
+      <section id="AddEditBook">
+        <item>
+          <attribute name="action">win.AddBook</attribute>
+          <attribute name="label" translatable="yes">_Add Bookmark</attribute>
+        </item>
+        <item>
+          <attribute name="action">win.EditBook</attribute>
+          <attribute name="label" translatable="no">%s...</attribute>
+        </item>
+      </section>
+''' % _('Organize Bookmarks'),  # Following are the Toolbar items
+    '''
+    <placeholder id='CommonNavigation'>
+    <child groups='RO'>
+      <object class="GtkToolButton">
+        <property name="icon-name">go-previous</property>
+        <property name="action-name">win.Back</property>
+        <property name="tooltip_text" translatable="yes">'''
+    '''Go to the previous object in the history</property>
+        <property name="label" translatable="yes">_Back</property>
+        <property name="use-underline">True</property>
+      </object>
+      <packing>
+        <property name="homogeneous">False</property>
+      </packing>
+    </child>
+    <child groups='RO'>
+      <object class="GtkToolButton">
+        <property name="icon-name">go-next</property>
+        <property name="action-name">win.Forward</property>
+        <property name="tooltip_text" translatable="yes">'''
+    '''Go to the next object in the history</property>
+        <property name="label" translatable="yes">_Forward</property>
+        <property name="use-underline">True</property>
+      </object>
+      <packing>
+        <property name="homogeneous">False</property>
+      </packing>
+    </child>
+    <child groups='RO'>
+      <object class="GtkToolButton">
+        <property name="icon-name">go-home</property>
+        <property name="action-name">win.HomePerson</property>
+        <property name="tooltip_text" translatable="yes">'''
+    '''Go to the default person</property>
+        <property name="label" translatable="yes">_Home</property>
+        <property name="use-underline">True</property>
+      </object>
+      <packing>
+        <property name="homogeneous">False</property>
+      </packing>
+    </child>
+    </placeholder>
+''',
+    '''
+    <placeholder id='BarCommonEdit'>
+    <child groups='RO'>
+      <object class="GtkToolButton">
+        <property name="icon-name">document-print</property>
+        <property name="action-name">win.PrintView</property>
+        <property name="tooltip_text" translatable="yes">'''
+    '''Print or save the Map</property>
+        <property name="label" translatable="yes">Print...</property>
+        <property name="use-underline">True</property>
+      </object>
+      <packing>
+        <property name="homogeneous">False</property>
+      </packing>
+    </child>
+    </placeholder>
+    ''']
+
+# pylint: disable=no-member
+# pylint: disable=unused-variable
+# pylint: disable=unused-argument
+
 
 #-------------------------------------------------------------------------
 #
@@ -114,7 +178,8 @@ _UI_DEF = '''\
 #-------------------------------------------------------------------------
 class GeoMoves(GeoGraphyView):
     """
-    The view used to render all places visited by one person and all his descendants.
+    The view used to render all places visited by one person and all
+    his descendants.
     """
     CONFIGSETTINGS = (
         ('geography.path', constants.GEOGRAPHY_PATH),
@@ -140,7 +205,7 @@ class GeoMoves(GeoGraphyView):
 
     def __init__(self, pdata, dbstate, uistate, nav_group=0):
         GeoGraphyView.__init__(self, _("Descendance of the active person."),
-                                      pdata, dbstate, uistate, 
+                                      pdata, dbstate, uistate,
                                       PersonBookmarks,
                                       nav_group)
         self.dbstate = dbstate
@@ -164,6 +229,7 @@ class GeoMoves(GeoGraphyView):
         self.markers_by_level = dict()
         self.count = dict()
         self.no_show_places_in_status_bar = False
+        self.person_list = []
 
     def get_title(self):
         """
@@ -174,11 +240,11 @@ class GeoMoves(GeoGraphyView):
     def get_stock(self):
         """
         Returns the name of the stock icon to use for the display.
-        This assumes that this icon has already been registered 
+        This assumes that this icon has already been registered
         as a stock icon.
         """
         return 'geo-show-family'
-    
+
     def get_viewtype_stock(self):
         """Type of view in category
         """
@@ -207,16 +273,14 @@ class GeoMoves(GeoGraphyView):
         self.place_list_active = []
         self.place_list_ref = []
         self.sort = []
-        self.places_found = []
-        self.place_without_coordinates = []
         self.remove_all_gps()
         self.remove_all_markers()
         self.lifeway_layer.clear_ways()
         self.date_layer.clear_dates()
         active = self.get_active()
         if active:
-            p1 = self.dbstate.db.get_person_from_handle(active)
-            self._createmap(p1)
+            person = self.dbstate.db.get_person_from_handle(active)
+            self._createmap(person)
         self.uistate.modify_statusbar(self.dbstate)
 
     def build_tree(self):
@@ -235,6 +299,7 @@ class GeoMoves(GeoGraphyView):
         self.lifeway_layer.clear_ways()
         self.date_layer.clear_dates()
         self.message_layer.clear_messages()
+        self.message_layer.set_font_attributes(None, None, None)
 
     def draw(self, menu, marks, color):
         """
@@ -261,7 +326,7 @@ class GeoMoves(GeoGraphyView):
 
     def _createmap_for_one_person(self, person, color):
         """
-        Create all markers for each people's event in the database which has 
+        Create all markers for each people's event in the database which has
         a lat/lon.
         """
         self.place_list = []
@@ -296,9 +361,9 @@ class GeoMoves(GeoGraphyView):
                         # place.get_longitude and place.get_latitude return
                         # one string. We have coordinates when the two values
                         # contains non null string.
-                        if ( longitude and latitude ):
+                        if longitude and latitude:
                             self._append_to_places_list(descr, evt,
-                                                        person.gramps_id, #_nd.display(person),
+                                                        person.gramps_id,
                                                         latitude, longitude,
                                                         descr1, eyear,
                                                         event.get_type(),
@@ -317,14 +382,17 @@ class GeoMoves(GeoGraphyView):
                 if family is not None:
                     fhandle = family_list[0] # first is primary
                     fam = dbstate.db.get_family_from_handle(fhandle)
+                    mother = father = None
                     handle = fam.get_father_handle()
-                    father = dbstate.db.get_person_from_handle(handle)
+                    if handle:
+                        father = dbstate.db.get_person_from_handle(handle)
                     if father:
                         descr1 = "%s - " % _nd.display(father)
                     handle = fam.get_mother_handle()
-                    mother = dbstate.db.get_person_from_handle(handle)
+                    if handle:
+                        mother = dbstate.db.get_person_from_handle(handle)
                     if mother:
-                        descr1 = "%s%s" % ( descr1, _nd.display(mother))
+                        descr1 = "%s%s" % (descr1, _nd.display(mother))
                     for event_ref in family.get_event_ref_list():
                         if event_ref:
                             event = dbstate.db.get_event_from_handle(
@@ -343,12 +411,15 @@ class GeoMoves(GeoGraphyView):
                                         descr = _pd.display(dbstate.db, place)
                                         evt = EventType(
                                                   event.get_type())
-                                        eyear = str("%04d" % event.get_date_object().to_calendar(self.cal).get_year()) + \
-                                                  str("%02d" % event.get_date_object().to_calendar(self.cal).get_month()) + \
-                                                  str("%02d" % event.get_date_object().to_calendar(self.cal).get_day())
-                                        if ( longitude and latitude ):
-                                            self._append_to_places_list(descr, evt,
-                                                 person.gramps_id, #_nd.display(person),
+                                        eyear = str(
+         "%04d" % event.get_date_object().to_calendar(self.cal).get_year()) + \
+     str("%02d" % event.get_date_object().to_calendar(self.cal).get_month()) + \
+     str("%02d" % event.get_date_object().to_calendar(self.cal).get_day())
+                                        if longitude and latitude:
+                                            self._append_to_places_list(
+                                                 descr,
+                                                 evt,
+                                                 person.gramps_id,
                                                  latitude, longitude,
                                                  descr1, eyear,
                                                  event.get_type(),
@@ -358,13 +429,13 @@ class GeoMoves(GeoGraphyView):
                                                  role
                                                  )
                                         else:
-                                            self._append_to_places_without_coord( place.gramps_id, descr)
+                                            self._append_to_places_without_coord(place.gramps_id, descr)
 
-            sort1 = sorted(self.place_list, key=operator.itemgetter(1,6))
+            sort1 = sorted(self.place_list, key=operator.itemgetter(1, 6))
             self.draw(None, sort1, color)
             # merge with the last results
             merge_list = self.sort
-            for the_event in sort1 :
+            for the_event in sort1:
                 if the_event not in merge_list:
                     merge_list.append(the_event)
             self.sort = sorted(merge_list, key=operator.itemgetter(6))
@@ -385,27 +456,36 @@ class GeoMoves(GeoGraphyView):
         Create all markers for one family : all event's places with a lat/lon.
         """
         dbstate = self.dbstate
+        person = None
         try:
-            person = dbstate.db.get_person_from_handle(family.get_father_handle())
+            person = dbstate.db.get_person_from_handle(
+                                                     family.get_father_handle())
         except:
             return
         family_id = family.gramps_id
         if person is None: # family without father ?
-            person = dbstate.db.get_person_from_handle(family.get_mother_handle())
+            handle = family.get_mother_handle()
+            if handle:
+                person = dbstate.db.get_person_from_handle(handle)
         if person is None:
-            person = dbstate.db.get_person_from_handle(self.uistate.get_active('Person'))
+            handle = self.uistate.get_active('Person')
+            if handle:
+                person = dbstate.db.get_person_from_handle(handle)
         if person is not None:
             self._add_person_to_list(person.gramps_id, curlevel-1)
             family_list = person.get_family_handle_list()
             for fhandle in family_list:
                 fam = dbstate.db.get_family_from_handle(fhandle)
+                father = mother = None
                 handle = fam.get_father_handle()
-                father = dbstate.db.get_person_from_handle(handle)
+                if handle:
+                    father = dbstate.db.get_person_from_handle(handle)
                 if father:
                     self._createmap_for_next_level(father, level-1, level)
                     self._add_person_to_list(father.gramps_id, curlevel-1)
                 handle = fam.get_mother_handle()
-                mother = dbstate.db.get_person_from_handle(handle)
+                if handle:
+                    mother = dbstate.db.get_person_from_handle(handle)
                 if mother:
                     self._createmap_for_next_level(father, level-1, level)
                     self._add_person_to_list(mother.gramps_id, curlevel-1)
@@ -416,7 +496,8 @@ class GeoMoves(GeoGraphyView):
                         child = dbstate.db.get_person_from_handle(child_ref.ref)
                         if child:
                             index += 1
-                            self._createmap_for_next_level(child, level, curlevel)
+                            self._createmap_for_next_level(child, level,
+                                                           curlevel)
                             self._add_person_to_list(child.gramps_id, curlevel)
 
     def _createmap_for_one_level(self, family, level, curlevel):
@@ -447,7 +528,7 @@ class GeoMoves(GeoGraphyView):
 
     def _createmap(self, person):
         """
-        Create all markers for each family's person in the database which has 
+        Create all markers for each family's person in the database which has
         a lat/lon.
         """
         dbstate = self.dbstate
@@ -459,88 +540,96 @@ class GeoMoves(GeoGraphyView):
         self.minlat = self.maxlat = self.minlon = self.maxlon = 0.0
         latitude = ""
         longitude = ""
+        self.places_found = []
+        self.nbplaces = 0
+        self.nbmarkers = 0
         self.message_layer.clear_messages()
         self.place_without_coordinates = []
         self.minlat = self.maxlat = self.minlon = self.maxlon = 0.0
         if person is None:
-            person = self.dbstate.db.get_person_from_handle(self.uistate.get_active('Person'))
+            handle = self.uistate.get_active('Person')
+            if handle:
+                person = self.dbstate.db.get_person_from_handle(handle)
             if not person:
                 return
-        self.message_layer.add_message(_("All descendance for %s") % _nd.display(person))
+        self.message_layer.add_message(
+                              _("All descendance for %s") % _nd.display(person))
         color = Gdk.color_parse(self._config.get('geography.color_base'))
         GLib.timeout_add(int(self._config.get("geography.generation_interval")),
                          self.animate_moves, 0, person, color)
 
     def animate_moves(self, index, person, color):
-            """
-            Animate all moves for one generation.
-            """
-            self.markers_by_level = dict()
-            self._createmap_for_next_level(person, index, 0)
-            try:
-                persons = self.markers_by_level[index]
-            except:
-                return
-            for people in persons:
-                family_list = people.get_family_handle_list()
-                for fhandle in family_list:
-                    family = self.dbstate.db.get_family_from_handle(fhandle)
-                    self._prepare_for_one_family(family, index, index+1)
-            new_list = []
-            for plx, level in self.person_list:
-                plxp = self.dbstate.db.get_person_from_gramps_id(plx)
-                birth = "0000"
-                death = "0000"
-                low_date = "9999" 
-                high_date = "0000"
-                for event_ref in plxp.get_event_ref_list():
-                    if not event_ref:
-                        continue
-                    event = self.dbstate.db.get_event_from_handle(event_ref.ref)
-                    role = event_ref.get_role()
-                    try:
-                        date = event.get_date_object().to_calendar(self.cal)
-                        fyear = str("%04d" % date.get_year())
-                        if event.get_type() == EventType.BIRTH:
-                           birth = fyear
-                        if event.get_type() == EventType.DEATH:
-                           death = fyear
-                        if fyear < low_date:
-                            low_date = fyear
-                        if fyear > high_date:
-                            high_date = fyear
+        """
+        Animate all moves for one generation.
+        """
+        self.markers_by_level = dict()
+        self._createmap_for_next_level(person, index, 0)
+        try:
+            persons = self.markers_by_level[index]
+        except:
+            return
+        for people in persons:
+            family_list = people.get_family_handle_list()
+            for fhandle in family_list:
+                family = self.dbstate.db.get_family_from_handle(fhandle)
+                self._prepare_for_one_family(family, index, index+1)
+        new_list = []
+        for plx, level in self.person_list:
+            plxp = self.dbstate.db.get_person_from_gramps_id(plx)
+            birth = "0000"
+            death = "0000"
+            low_date = "9999"
+            high_date = "0000"
+            for event_ref in plxp.get_event_ref_list():
+                if not event_ref:
+                    continue
+                event = self.dbstate.db.get_event_from_handle(event_ref.ref)
+                role = event_ref.get_role()
+                try:
+                    date = event.get_date_object().to_calendar(self.cal)
+                    fyear = str("%04d" % date.get_year())
+                    if event.get_type() == EventType.BIRTH:
+                        birth = fyear
+                    if event.get_type() == EventType.DEATH:
+                        death = fyear
+                    if fyear < low_date:
+                        low_date = fyear
+                    if fyear > high_date:
+                        high_date = fyear
 
-                    except:
-                        pass
-                    if birth == "0000":
-                        birth = low_date
-                    if death == "0000":
-                        death = high_date
-                new_list.append([level, plxp, birth, death])
-            pidx = 0;
-            if isinstance(color, str) :
-                color = Gdk.color_parse(color)
-            for (level, plxp, birth, death) in sorted(new_list, key=operator.itemgetter(0,2)):
-                if index == int(self._config.get("geography.maximum_generations")):
-                   break
-                if level == index:
-                    pidx += 1
-                    self._createmap_for_one_person(plxp, color)
-                    color.red = (float(color.red - (index)*3000)%65535)
-                    if ( index % 2 ):
-                        color.green = float((color.green + (index)*3000)%65535)
-                    else:
-                        color.blue = float((color.blue + (index)*3000)%65535)
-                    self._createmap_for_one_person(person, color)
-            if index < int(self._config.get("geography.maximum_generations")):
-                time_to_wait = int(self._config.get("geography.generation_interval"))
-                self._create_markers()
-                # process next generation in a few milliseconds
-                GLib.timeout_add(int(time_to_wait), self.animate_moves,
-                                                  index+1, person, color)
-            else:
-                self.started = False
-            return False
+                except:
+                    pass
+                if birth == "0000":
+                    birth = low_date
+                if death == "0000":
+                    death = high_date
+            new_list.append([level, plxp, birth, death])
+        pidx = 0
+        if isinstance(color, str):
+            color = Gdk.color_parse(color)
+        for (level, plxp,
+             birth, death) in sorted(new_list, key=operator.itemgetter(0, 2)):
+            if index == int(self._config.get("geography.maximum_generations")):
+                break
+            if level == index:
+                pidx += 1
+                self._createmap_for_one_person(plxp, color)
+                color.red = (float(color.red - (index)*3000)%65535)
+                if index % 2:
+                    color.green = float((color.green + (index)*3000)%65535)
+                else:
+                    color.blue = float((color.blue + (index)*3000)%65535)
+                self._createmap_for_one_person(person, color)
+        if index < int(self._config.get("geography.maximum_generations")):
+            time_to_wait = int(
+                              self._config.get("geography.generation_interval"))
+            self._create_markers()
+            # process next generation in a few milliseconds
+            GLib.timeout_add(int(time_to_wait), self.animate_moves,
+                                              index+1, person, color)
+        else:
+            self.started = False
+        return False
 
     def bubble_message(self, event, lat, lon, marks):
         """
@@ -554,7 +643,7 @@ class GeoMoves(GeoGraphyView):
         oldplace = ""
         prevmark = None
         # Be sure all markers are sorted by place then dates.
-        for mark in sorted(marks, key=operator.itemgetter(0,6)):
+        for mark in sorted(marks, key=operator.itemgetter(0, 6)):
             if mark[10] in events:
                 continue # avoid duplicate events
             else:
@@ -571,19 +660,20 @@ class GeoMoves(GeoGraphyView):
             date = displayer.display(evt.get_date_object())
             if date == "":
                 date = _("Unknown")
-            if ( mark[11] == EventRoleType.PRIMARY ):
+            if mark[11] == EventRoleType.PRIMARY:
                 person = self.dbstate.db.get_person_from_gramps_id(mark[1])
-                message = "(%s) %s : %s" % ( date, mark[2], _nd.display(person) )
-            elif ( mark[11] == EventRoleType.FAMILY ):
-                (father_name, mother_name) = self._get_father_and_mother_name(evt)
+                message = "(%s) %s : %s" % (date, mark[2], _nd.display(person))
+            elif mark[11] == EventRoleType.FAMILY:
+                (father_name,
+                 mother_name) = self._get_father_and_mother_name(evt)
                 message = "(%s) %s : %s - %s" % (date, mark[2],
                                                  father_name,
-                                                 mother_name )
+                                                 mother_name)
             else:
                 descr = evt.get_description()
                 if descr == "":
                     descr = _('No description')
-                message = "(%s) %s => %s" % ( date, mark[11], descr)
+                message = "(%s) %s => %s" % (date, mark[11], descr)
             prevmark = mark
             add_item = Gtk.MenuItem(label=message)
             add_item.show()
@@ -610,16 +700,14 @@ class GeoMoves(GeoGraphyView):
             bookm.connect("activate", self.add_bookmark_from_popup, hdle)
             itemoption.append(bookm)
             menu.show()
-            menu.popup(None, None,
-                       lambda menu, data: (event.get_root_coords()[0],
-                                           event.get_root_coords()[1], True),
+            menu.popup(None, None, None,
                        None, event.button, event.time)
         return 1
 
-    def add_specific_menu(self, menu, event, lat, lon): 
-        """ 
+    def add_specific_menu(self, menu, event, lat, lon):
+        """
         Add specific entry to the navigation menu.
-        """ 
+        """
         return
 
     def get_default_gramplets(self):
@@ -634,25 +722,25 @@ class GeoMoves(GeoGraphyView):
         Add specific entry to the preference menu.
         Must be done in the associated view.
         """
-        table = Gtk.Table(n_rows=2, n_columns=2)
-        table.set_border_width(12)
-        table.set_col_spacings(6)
-        table.set_row_spacings(6)
-        configdialog.add_text(table,
+        grid = Gtk.Grid()
+        grid.set_border_width(12)
+        grid.set_column_spacing(6)
+        grid.set_row_spacing(6)
+        configdialog.add_text(grid,
                 _('The maximum number of generations.\n'),
                 1, line_wrap=False)
-        configdialog.add_slider(table, 
-                "", 
+        configdialog.add_slider(grid,
+                "",
                 2, 'geography.maximum_generations',
                 (1, 20))
-        configdialog.add_text(table,
+        configdialog.add_text(grid,
                 _('Time in milliseconds between drawing two generations.\n'),
                 3, line_wrap=False)
-        configdialog.add_slider(table, 
-                "", 
+        configdialog.add_slider(grid,
+                "",
                 4, 'geography.generation_interval',
                 (500, 3000))
-        return _('The parameters for moves'), table
+        return _('The parameters for moves'), grid
 
     def config_connect(self):
         """
